@@ -1,10 +1,7 @@
-#!/usr/bin/perl -w
-
-eval 'exec /usr/bin/perl -w -S $0 ${1+"$@"}'
-    if 0; # not running under some shell
+#!/usr/bin/perl 
 use strict;
+use warnings;
 use Carp;
-# $Id: aacomp.PLS 15088 2008-12-04 02:49:09Z bosborne $
 
 use Bio::SeqIO;
 use Getopt::Long;
@@ -68,15 +65,15 @@ __END__
 
 =head1 NAME
 
-aacomp - amino acid composition of protein sequences
+bp_aacomp - amino acid composition of protein sequences
 
 =head1 SYNOPSIS
 
-  aacomp [-f/--format FORMAT] [-h/--help] filename
+  bp_aacomp [-f/--format FORMAT] [-h/--help] filename
   or
-  aacomp [-f/--format FORMAT] < filename
+  bp_aacomp [-f/--format FORMAT] < filename
   or
-  aacomp [-f/--format FORMAT] -i filename
+  bp_aacomp [-f/--format FORMAT] -i filename
 
 =head1 DESCRIPTION
 
@@ -93,15 +90,15 @@ The sequence input can be provided using any of the three methods:
 
 =item unnamed argument
 
-  aacomp filename
+  bp_aacomp filename
 
 =item named argument
 
-  aacomp -i filename
+  bp_aacomp -i filename
 
 =item standard input
 
-  aacomp < filename
+  bp_aacomp < filename
 
 =back
 
@@ -122,7 +119,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via the
 web:
 
-  http://bugzilla.open-bio.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Jason Stajich
 
