@@ -1,11 +1,8 @@
-#!/usr/bin/perl -w
-
-eval 'exec /usr/bin/perl -w -S $0 ${1+"$@"}'
-    if 0; # not running under some shell
-# $Id: biofetch_genbank_proxy.PLS 15088 2008-12-04 02:49:09Z bosborne $
+#!/usr/bin/perl 
 
 # dbfetch style caching proxy for GenBank
 use strict;
+use warnings;
 use CGI qw(:standard);
 use HTTP::Request::Common;
 use LWP::UserAgent;
@@ -128,7 +125,7 @@ A URL for biofetch consists of four sections:
 			e.g.
 1. protocol		http://
 2. host			www.ebi.ac.uk
-3. path to program	/cgi-bin/dbfetch
+3. path to program	/Tools/dbfetch/dbfetch
 4. query string		?style=raw;format=embl;db=embl;id=J00231
 
 
@@ -226,7 +223,7 @@ __END__
 
 =head1 NAME
 
-biofetch_genbank_proxy.pl - Caching BioFetch-compatible web proxy for GenBank
+bp_biofetch_genbank_proxy.pl - Caching BioFetch-compatible web proxy for GenBank
 
 =head1 SYNOPSIS
 
