@@ -1,12 +1,9 @@
-#!/usr/bin/perl -w
+#!/usr/bin/perl 
 
-eval 'exec /usr/bin/perl -w -S $0 ${1+"$@"}'
-    if 0; # not running under some shell
-#$Id: bioflat_index.PLS 15088 2008-12-04 02:49:09Z bosborne $
 
 =head1 NAME
 
-bioflat_index.pl - index sequence files using Bio::DB::Flat
+bp_bioflat_index.pl - index sequence files using Bio::DB::Flat
 
 =head1 DESCRIPTION
 
@@ -16,7 +13,7 @@ bioflat_index.pl - index sequence files using Bio::DB::Flat
 
 =head1 USAGE
 
- bioflat_index.pl <options> file1 file2 file3...
+ bp_bioflat_index.pl <options> file1 file2 file3...
 
  Options:
 
@@ -47,6 +44,7 @@ corresponding options are not provided:
 =cut
 
 use strict;
+use warnings;
 use Bio::Root::Root;
 use Bio::Root::IO;
 use Bio::DB::Flat;
