@@ -1,8 +1,4 @@
-#!/usr/bin/perl -w
-
-eval 'exec /usr/bin/perl -w -S $0 ${1+"$@"}'
-    if 0; # not running under some shell
-# $Id: biogetseq.PLS 15088 2008-12-04 02:49:09Z bosborne $
+#!/usr/bin/perl 
 #
 # OBDA Registry compliant sequence retrieval script
 #
@@ -14,6 +10,7 @@ use Bio::DB::Registry;
 use Bio::SeqIO;
 use Getopt::Long;
 use strict;
+use warnings;
 
 my ($help, $format, $namespace, $dbname) = ('', 'embl', 'acc', 'embl');
 GetOptions ("help" => \$help, "format=s" => \$format,
@@ -40,7 +37,7 @@ while (my $id = shift) {
 
 =head1 NAME
 
-biogetseq - sequence retrieval using OBDA registry
+bp_biogetseq - sequence retrieval using OBDA registry
 
 =head1 DESCRIPTION
 
@@ -50,7 +47,7 @@ file, sql database or over the web.
 
 =head1 USAGE
 
-  Usage: biogetseq --dbname embl --format embl
+  Usage: bp_biogetseq --dbname embl --format embl
                    --namespace acc id [ ids... ]
          * dbname defaults to embl
          * format defaults to embl
