@@ -1,10 +1,7 @@
 #!/usr/bin/perl 
 
-eval 'exec /usr/bin/perl  -S $0 ${1+"$@"}'
-    if 0; # not running under some shell
-# $Id: bulk_load_gff.PLS 15088 2008-12-04 02:49:09Z bosborne $
-
 use strict;
+use warnings;
 # use lib './blib/lib';
 use DBI;
 use IO::File;
@@ -23,11 +20,11 @@ use constant FATTRIBUTE_TO_FEATURE => 'fattribute_to_feature';
 
 =head1 NAME
 
-bulk_load_gff.pl - Bulk-load a Bio::DB::GFF database from GFF files.
+bp_bulk_load_gff.pl - Bulk-load a Bio::DB::GFF database from GFF files.
 
 =head1 SYNOPSIS
 
-  % bulk_load_gff.pl -d testdb dna1.fa dna2.fa features1.gff features2.gff ...
+  % bp_bulk_load_gff.pl -d testdb dna1.fa dna2.fa features1.gff features2.gff ...
 
 =head1 DESCRIPTION
 
@@ -102,6 +99,9 @@ e.g. -d instead of --database.
    --group               A list of one or more tag names (comma or space separated)
                          to be used for grouping in the 9th column.
    --gff3_munge          Activate GFF3 name munging (see Bio::DB::GFF)
+   --summary             Generate summary statistics for drawing coverage histograms.
+                           This can be run on a previously loaded database or during
+                           the load.
    --Temporary           Location of a writable scratch directory
 
 =head1 SEE ALSO
@@ -231,6 +231,7 @@ unless ($FORCE) {
   die "Aborted\n" unless $f =~ /^[yY]/;
   close TTY;
 }
+
 # postgres DBD::Pg allows 'database', but also 'dbname', and 'db':
 # and it must be Pg (not pg)
 $DSN=~s/pg:database=/Pg:/i;
@@ -467,6 +468,7 @@ while (<>) {
 
   elsif (/^\#\#\s*gff-version\s+(\d+)/) {
     $gff3 = ($1 >= 3);
+    $db->print_gff3_warning() if $gff3;
     next;
   }
 
@@ -640,7 +642,6 @@ elsif( $use_mysql or $use_mysqlcmap ) {
 
   if ($success) {
     print "$FEATURES features successfully loaded\n";
-    exit 0;
   } else {
     print "FAILURE: Please see standard error for details\n";
     exit -1;
@@ -651,6 +652,21 @@ foreach (@fasta_files_to_be_unlinked) {
   unlink "$tmpdir/$_.$$";
 }
 
+warn "Building summary statistics for coverage histograms...\n";
+my (@args,$AUTH);
+if (defined $USER) {
+  push @args,(-user=>$USER);
+  $AUTH .= " -u$USER";
+}
+if (defined $PASSWORD) {
+  push @args,(-pass=>$PASSWORD);
+  $AUTH .= " -p$PASSWORD";
+}
+push @args,(-preferred_groups=>[split(/[,\s+]+/,$GROUP_TAG)]) if defined $GROUP_TAG;
+my $db = Bio::DB::GFF->new(-adaptor=>"dbi::$ADAPTOR",-dsn => $DSN,@args)
+  or die "Can't open database: ",Bio::DB::GFF->error,"\n";
+$db->build_summary_statistics;
+
 exit 0;
 
 sub function_to_table {
