@@ -1,10 +1,10 @@
-#!/usr/bin/perl -w
+#!/usr/bin/perl 
 
-eval 'exec /usr/bin/perl -w -S $0 ${1+"$@"}'
+eval 'exec /usr/bin/perl  -S $0 ${1+"$@"}'
     if 0; # not running under some shell
-# $Id: chaos_plot.PLS 15088 2008-12-04 02:49:09Z bosborne $
 
 use strict;
+use warnings;
 
 use Bio::SeqIO;
 use Getopt::Long;
@@ -86,22 +86,23 @@ for( my $i = 1; $i <= $len; $i++ ) {
 
     $img->setPixel($x * $width,$y * $height, $black);
 }
-open(OUT, ">$output");
-binmode OUT;
+open my $OUT, '>', $output or die "Could not write file '$output': $!\n";
+binmode $OUT;
 $graph =~ s/jpg/jpeg/;
 
-print OUT $img->$graph();
+print $OUT $img->$graph();
+close $OUT;
 
 
 __END__
 
 =head1 NAME
 
-chaos_plot - a chaos plot from DNA and RNA sequences
+bp_chaos_plot - a chaos plot from DNA and RNA sequences
 
 =head1 SYNOPSIS
 
-  chaos_plot.pl -i/--input=INPUTFILE -f/--format=SEQFORMAT
+  bp_chaos_plot.pl -i/--input=INPUTFILE -f/--format=SEQFORMAT
         -o/--output=OUTPUTFILE -g/--graphics=GRAPHIC FORMAT
         -w/--width=WIGHT -h/--height=HEIGHT
 
@@ -122,15 +123,15 @@ The sequence input can be provided using any of the three methods:
 
 =item unnamed argument
 
-  chaos_plot filename
+  bp_chaos_plot filename
 
 =item named argument
 
-  chaos_plot -i filename
+  bp_chaos_plot -i filename
 
 =item standard input
 
-  chaos_plot < filename
+  bp_chaos_plot < filename
 
 =back
 
@@ -151,7 +152,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via the
 web:
 
-  http://bugzilla.open-bio.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Jason Stajich
 
@@ -168,4 +169,3 @@ UK) rd@mrc-lmba.cam.ac.uk, and Jean Thierry-Mieg (CRBM du CNRS,
 France) mieg@crbm1.cnusc.fr
 
 =cut
-
