@@ -1,17 +1,16 @@
-#!/usr/bin/perl -w
+#!/usr/bin/perl 
 
-eval 'exec /usr/bin/perl -w -S $0 ${1+"$@"}'
+eval 'exec /usr/bin/perl  -S $0 ${1+"$@"}'
     if 0; # not running under some shell
 # -*-Perl-*- 
-# $Id: composite_LD.PLS 15088 2008-12-04 02:49:09Z bosborne $
 
 =head1 NAME 
 
-composite_LD -i filename.prettybase.txt --sortbyld E<gt> outfile
+bp_composite_LD -i filename.prettybase.txt --sortbyld E<gt> outfile
 
 =head1 SYNOPSIS
 
-  composite_LD -i filename.prettybase [-o out.LD] [-f prettybase/csv] [--sortbyld] [--noconvertindels]
+  bp_composite_LD -i filename.prettybase [-o out.LD] [-f prettybase/csv] [--sortbyld] [--noconvertindels]
 
 =head2 DESCRIPTION
 
@@ -45,6 +44,7 @@ Jason Stajich E<lt>jason-at-bioperl-dot-orgE<gt>
 =cut
 
 use strict;
+use warnings;
 
 use Bio::PopGen::IO;
 use Bio::PopGen::Statistics;
@@ -84,7 +84,7 @@ my %LD_matrix = $stats->composite_LD($pop);
 my @sites;
 my $out;
 if( $outfile ) { 
-    open($out, ">$outfile") || die("$outfile: $!");
+    open $out, '>', $outfile or die "Could not write file '$outfile': $!\n";
 } else { 
     $out = \*STDOUT;
 }
@@ -105,6 +105,3 @@ if( $sortbyld ) {
 	print $out "$site1,$site2 - LD=$ld, chisq=$chisq\n";
     }
 }
-
-
-
