@@ -1,16 +1,16 @@
-#!/usr/bin/perl -w
+#!/usr/bin/perl 
 
-eval 'exec /usr/bin/perl -w -S $0 ${1+"$@"}'
+eval 'exec /usr/bin/perl  -S $0 ${1+"$@"}'
     if 0; # not running under some shell
 #-*-Perl-*-
 
 =head1 NAME
 
-dbsplit - script to split an input set of database(s) into smaller pieces
+bp_dbsplit - script to split an input set of database(s) into smaller pieces
 
 =head1 SYNOPSIS
 
-  dbsplit.PLS --size 50 [-i inputfile] [-if inputformat] [-of outputformat]
+  bp_dbsplit.PLS --size 50 [-i inputfile] [-if inputformat] [-of outputformat]
               [--prefix outputprefix] [ < file1 file 2  OR file1 file2]
 
 =head1 DESCRIPTION
@@ -24,11 +24,11 @@ supported by bioperl (fasta,embl,genbank,gcg, swissprot, etc).
 You can specify the input data either as a single file with -i
 filename, or as a single file as an argument like
 
-  % dbsplit file1 file2
+  % bp_dbsplit file1 file2
 
 or as a list of sequence data with 
 
-  % cat file1 file2 file3 | dbsplit
+  % cat file1 file2 file3 | bp_dbsplit
 
 You'll want to use the C<--prefix> to specify what the output prefix will
 be.
@@ -50,7 +50,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via
 the web:
 
-  http://bugzilla.open-bio.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR
 
@@ -59,6 +59,7 @@ Jason Stajich, jason-at-bioperl-dot-org
 =cut
 
 use strict;
+use warnings;
 use Bio::SeqIO;
 use Bio::SeqIO::MultiFile;
 
