@@ -1,10 +1,7 @@
 #!/usr/bin/perl 
 
-eval 'exec /usr/bin/perl  -S $0 ${1+"$@"}'
-    if 0; # not running under some shell
-# $Id: fast_load_gff.PLS 15088 2008-12-04 02:49:09Z bosborne $
-
 use strict;
+use warnings;
 # use lib './blib/lib';
 use DBI;
 use IO::File;
@@ -97,6 +94,9 @@ e.g. -d instead of --database.
    --group               A list of one or more tag names (comma or space separated)
                          to be used for grouping in the 9th column.
    --gff3_munge          Activate GFF3 name munging (see Bio::DB::GFF)
+   --summary             Generate summary statistics for drawing coverage histograms.
+                           This can be run on a previously loaded database or during
+                           the load.
    --Temporary           Location of a writable scratch directory
 
 =head1 SEE ALSO
@@ -132,7 +132,7 @@ package main;
 eval "use Time::HiRes"; undef $@;
 my $timer = defined &Time::HiRes::time;
 
-my ($DSN,$CREATE,$USER,$PASSWORD,$FASTA,$FAILED,$LOCAL,%PID,$MAX_BIN,$GROUP_TAG,$LONG_LIST,$MUNGE,$TMPDIR);
+my ($DSN,$CREATE,$USER,$PASSWORD,$FASTA,$FAILED,$LOCAL,%PID,$MAX_BIN,$GROUP_TAG,$LONG_LIST,$MUNGE,$TMPDIR,$SUMMARY_STATS);
 
 if ($DO_FAST) {
   $SIG{CHLD} = sub {
@@ -155,6 +155,7 @@ GetOptions ('database:s'    => \$DSN,
 	    'long_list:s'   => \$LONG_LIST,
             'maxbin|maxfeature:s'    => \$MAX_BIN,
 	    'gff3_munge'    => \$MUNGE,
+	    'summary'       => \$SUMMARY_STATS,
 	    'Temporary:s'   => \$TMPDIR,
 	   ) or (system('pod2text',$0), exit -1);
 
@@ -178,6 +179,7 @@ my $db = Bio::DB::GFF->new(-adaptor=>'faux',-dsn => $DSN,@args)
 $db->gff3_name_munging(1) if $MUNGE;
 
 if ($CREATE) {
+  $SUMMARY_STATS++;
   $MAX_BIN ? $db->initialize(-erase=>1,-MAX_BIN=>$MAX_BIN) : $db->initialize(1);
 }
 
@@ -230,8 +232,8 @@ my $can_disable_indexes = ($major >= 4 and $minor >= 0);
 
 # open up pipes to the database
 my (%FH,%COMMAND);
-my $MYSQL = MYSQL;
-my $tmpdir = $TMPDIR || $ENV{TMPDIR} || $ENV{TMP} || '/usr/tmp';
+my $MYSQL  = MYSQL;
+my $tmpdir = $TMPDIR || $ENV{TMPDIR} || $ENV{TMP} || File::Spec->tmpdir();
 -d $tmpdir or die <<END;
 I could not find a suitable temporary directory to write scratch files into ($tmpdir by default).
 Please select a directory and indicate its location by setting the TMP environment variable, or
@@ -330,6 +332,7 @@ while (<>) {
 
   elsif (/^\#\#\s*gff-version\s+(\d+)/) {
     $gff3 = ($1 >= 3);
+    $db->print_gff3_warning() if $gff3;
     next;
   }
 
@@ -442,6 +445,11 @@ if ($success) {
   exit -1;
 }
 
+if ($SUMMARY_STATS) {
+    warn "Building summary statistics for coverage histograms...\n";
+    $db->build_summary_statistics;
+}
+
 exit 0;
 
 sub cleanup {
