@@ -1,6 +1,6 @@
-#!/usr/bin/perl -w
+#!/usr/bin/perl 
 
-eval 'exec /usr/bin/perl -w -S $0 ${1+"$@"}'
+eval 'exec /usr/bin/perl  -S $0 ${1+"$@"}'
     if 0; # not running under some shell
 
 =head1 NAME 
@@ -13,7 +13,7 @@ fastm9_to_table  - turn FASTA -m 9 output into NCBI -m 9 tabular output
 
 =head1 DESCRIPTION
 
-Comand line options:
+Command line options:
   -e/--evalue   evalue    -- filter by evalue
   -b/--bitscore bitscore  -- filter by bitscore
   --header                -- boolean flag to print column header 
@@ -54,6 +54,7 @@ Jason Stajich jason_at_bioperl-dot-org
 =cut
 
 use strict;
+use warnings;
 use Getopt::Long;
 my $hitsection = 0;
 my %data;
@@ -69,7 +70,7 @@ GetOptions(
 
 my $outfh;
 if( $outfile ) { 
-    open($outfh, ">$outfile") || die("$outfile: $!");
+    open $outfh, '>', $outfile or die "Could not write file '$outfile': $!\n";
 } else { 
     $outfh = \*STDOUT; 
 }
