@@ -1,19 +1,18 @@
-#!/usr/bin/perl -w
+#!/usr/bin/perl 
 
-eval 'exec /usr/bin/perl -w -S $0 ${1+"$@"}'
+eval 'exec /usr/bin/perl  -S $0 ${1+"$@"}'
     if 0; # not running under some shell
 use strict;
-
-# $Id: filter_search.PLS 15088 2008-12-04 02:49:09Z bosborne $
+use warnings;
 
 
 =head1 NAME
 
-filter_search - filters searchio results, outputting a tab delimited summary
+bp_filter_search - filters searchio results, outputting a tab delimited summary
 
 =head1 SYNOPSIS
 
-  #filter_search -format blast -score 200 < search.bl > search.tab
+  #bp_filter_search -format blast -score 200 < search.bl > search.tab
 
 =head1 DESCRIPTION 
 
@@ -38,7 +37,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via
 email or the web:
 
-  http://bugzilla.open-bio.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR
 
