@@ -3,7 +3,6 @@
 eval 'exec /usr/bin/perl  -S $0 ${1+"$@"}'
     if 0; # not running under some shell
 # -*-Perl-*-
-# $Id: flanks.PLS 15088 2008-12-04 02:49:09Z bosborne $
 #
 # Heikki Lehvaslaiho <heikki-at-bioperl-dot-org>
 # Finding flanking sequences for a variant.
@@ -22,6 +21,7 @@ use Bio::DB::EMBL;
 use Bio::DB::GenBank;
 use Getopt::Long;
 use strict;
+use warnings;
 
 use constant VERSION => '3.0';
 
@@ -187,11 +187,11 @@ sub extract {
 
 =head1 NAME
 
-flanks - finding flanking sequences for a variant in a sequence position
+bp_flanks - finding flanking sequences for a variant in a sequence position
 
 =head1 SYNOPSIS
 
-  flanks --position POS [-p POS ...]  [--flanklen INT]
+  bp_flanks --position POS [-p POS ...]  [--flanklen INT]
          accession | filename
 
 =head1 DESCRIPTION
@@ -275,7 +275,7 @@ upper case and rest of the sequence in lower case characters.
 
 =head1 EXAMPLE
 
-  % flanks ~/seq/ar.embl
+  % bp_flanks ~/seq/ar.embl
 
   >1_/HOME/HEIKKI/SEQ/AR.EMBL oripos=100 strand=1 allelepos=100
   taataactcagttcttatttgcacctacttcagtggacactgaatttggaaggtggagga
@@ -308,7 +308,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 the bugs and their resolution.  Bug reports can be submitted via the
 web:
 
-  http://bugzilla.open-bio.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Heikki Lehvaslaiho
 
