@@ -1,10 +1,10 @@
-#!/usr/bin/perl -w
+#!/usr/bin/perl 
 
-eval 'exec /usr/bin/perl -w -S $0 ${1+"$@"}'
+eval 'exec /usr/bin/perl  -S $0 ${1+"$@"}'
     if 0; # not running under some shell
-# $Id: gccalc.PLS 15635 2009-04-14 19:11:13Z cjfields $
 
 use strict;
+use warnings;
 
 use Bio::SeqIO;
 use Bio::Tools::SeqStats;
@@ -82,15 +82,15 @@ __END__
 
 =head1 NAME
 
-gccalc - GC content of nucleotide sequences
+bp_gccalc - GC content of nucleotide sequences
 
 =head1 SYNOPSIS
 
-  gccalc [-f/--format FORMAT] [-h/--help] filename
+  bp_gccalc [-f/--format FORMAT] [-h/--help] filename
   or
-  gccalc [-f/--format FORMAT] < filename
+  bp_gccalc [-f/--format FORMAT] < filename
   or
-  gccalc [-f/--format FORMAT] -i filename
+  bp_gccalc [-f/--format FORMAT] -i filename
 
 =head1 DESCRIPTION
 
@@ -107,15 +107,15 @@ The sequence input can be provided using any of the three methods:
 
 =item unnamed argument
 
-  gccalc filename
+  bp_gccalc filename
 
 =item named argument
 
-  gccalc -i filename
+  bp_gccalc -i filename
 
 =item standard input
 
-  gccalc < filename
+  bp_gccalc < filename
 
 =back
 
@@ -136,7 +136,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via the
 web:
 
-  http://bugzilla.open-bio.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Jason Stajich
 
