@@ -1,12 +1,9 @@
-#!/usr/bin/perl -w
-
-eval 'exec /usr/bin/perl -w -S $0 ${1+"$@"}'
-    if 0; # not running under some shell
+#!/usr/bin/perl 
 
 use lib '.';
 
-# $Id: genbank2gff.PLS 15088 2008-12-04 02:49:09Z bosborne $
 use strict;
+use warnings;
 use Bio::DB::GFF;
 use Getopt::Long;
 
@@ -254,13 +251,14 @@ elsif ($accFILE){
     my $filename = shift;
     die "you must supply a filename after the --accFILE command line flag\n" unless $filename;
     die "file $filename does not exist\n" unless (-e $filename && !(-d $filename));
-    open IN, "$filename" || die "Can't open file $filename for reading accession numbers: $!\n";
-    while (<IN>){
-        chomp;
-	status(loading => $_);
-        my $result = $db->load_from_embl(/^NC_/?'refseq':'embl' => $_);
+    open my $IN, '<', $filename or die "Could not read file '$filename' for reading accession numbers: $!\n";
+    while (my $line = <$IN>){
+        chomp $line;
+	status(loading => $line);
+        my $result = $db->load_from_embl(/^NC_/?'refseq':'embl' => $line);
 	status(done => $result);
     }
+    close $IN;
     exit 1;
 }
 
