@@ -1,10 +1,7 @@
 #!/usr/bin/perl 
 
-eval 'exec /usr/bin/perl  -S $0 ${1+"$@"}'
-    if 0; # not running under some shell
-# $Id: generate_histogram.PLS 15088 2008-12-04 02:49:09Z bosborne $
-
 use strict;
+use warnings;
 use lib '.','./blib','../../blib/lib';
 use Bio::DB::GFF;
 use Getopt::Long;
@@ -93,11 +90,11 @@ __END__
 
 =head1 NAME
 
-generate_histogram.pl -- Generate a histogram of Bio::DB::GFF features
+bp_generate_histogram.pl -- Generate a histogram of Bio::DB::GFF features
 
 =head1 SYNOPSIS
 
-  generate_histogram.pl -d gadfly variation gene:curated
+  bp_generate_histogram.pl -d gadfly variation gene:curated
 
 =head1 DESCRIPTION
 
