@@ -1,15 +1,15 @@
-#!/usr/bin/perl -w
+#!/usr/bin/perl 
 
-eval 'exec /usr/bin/perl -w -S $0 ${1+"$@"}'
+eval 'exec /usr/bin/perl  -S $0 ${1+"$@"}'
     if 0; # not running under some shell
 # -*-Perl-*- (for my emacs)
-# $Id: heterogeneity_test.PLS 15088 2008-12-04 02:49:09Z bosborne $
 
 use strict;
+use warnings;
 
 =head1 NAME 
 
-heterogeneity_test - a test for distinguishing between selection and population expansion.
+bp_heterogeneity_test - a test for distinguishing between selection and population expansion.
 
 =head1 SYNOPSIS
 
