@@ -1,9 +1,7 @@
 #!/usr/bin/perl 
 
-eval 'exec /usr/bin/perl  -S $0 ${1+"$@"}'
-    if 0; # not running under some shell
-
 use strict;
+use warnings;
 use lib '../blib/lib';
 use Bio::DB::GFF;
 use Getopt::Long;
@@ -70,10 +68,13 @@ e.g. -d instead of --database.
    --upgrade             Upgrade existing database to current schema
    --gff3_munge          Activate GFF3 name munging (see Bio::DB::GFF)
    --quiet               No progress reports
+   --summary             Generate summary statistics for drawing coverage histograms.
+                           This can be run on a previously loaded database or during
+                           the load.
 
 =head1 SEE ALSO
 
-L<Bio::DB::GFF>, L<bulk_load_gff.pl>, L<load_gff.pl>
+L<Bio::DB::GFF>, L<bulk_load_gff.pl>, L<bp_load_gff.pl>
 
 =head1 AUTHOR
 
@@ -87,19 +88,20 @@ disclaimers of warranty.
 
 =cut
 
-my ($DSN,$ADAPTOR,$CREATE,$USER,$PASSWORD,$FASTA,$UPGRADE,$MAX_BIN,$GROUP_TAG,$MUNGE,$QUIET);
+my ($DSN,$ADAPTOR,$CREATE,$USER,$PASSWORD,$FASTA,$UPGRADE,$MAX_BIN,$GROUP_TAG,$MUNGE,$QUIET,$SUMMARY_STATS);
 
-GetOptions ('dsn:s'       => \$DSN,
-				'adaptor:s'   => \$ADAPTOR,
-				'u|user:s'    => \$USER,
-				'p|password:s' => \$PASSWORD,
-            'fasta:s'     => \$FASTA,
-            'upgrade'     => \$UPGRADE,
+GetOptions ('dsn:s'                  => \$DSN,
+	    'adaptor:s'              => \$ADAPTOR,
+	    'u|user:s'               => \$USER,
+	    'p|password:s'           => \$PASSWORD,
+            'fasta:s'                => \$FASTA,
+            'upgrade'                => \$UPGRADE,
             'maxbin|maxfeature:s'    => \$MAX_BIN,
-	         'group:s'     => \$GROUP_TAG,
-	         'gff3_munge'    => \$MUNGE,
-	         'quiet'       => \$QUIET,
-	         create        => \$CREATE) or (system('pod2text',$0), exit -1);
+	    'group:s'                => \$GROUP_TAG,
+	    'gff3_munge'             => \$MUNGE,
+	    'quiet'                  => \$QUIET,
+	    'summary'                => \$SUMMARY_STATS,
+	    'create'                 => \$CREATE) or (system('pod2text',$0), exit -1);
 
 # some local defaults
 $DSN     ||= 'dbi:mysql:test';
@@ -119,8 +121,9 @@ my $db = Bio::DB::GFF->new(-adaptor=>$ADAPTOR,-dsn => $DSN,@args)
 $db->gff3_name_munging(1) if $MUNGE;
 
 if ($CREATE) {
-  $MAX_BIN ? $db->initialize(-erase=>1,-MAX_BIN=>$MAX_BIN) :
-             $db->initialize(1);
+    $SUMMARY_STATS++;
+    $MAX_BIN ? $db->initialize(-erase=>1,-MAX_BIN=>$MAX_BIN) :
+               $db->initialize(1);
 } elsif ($UPGRADE) {
   warn qq(expect to see several "table already exists" messages\n);
   $db->initialize(0);
@@ -156,3 +159,8 @@ for my $file (@fasta) {
   my $loaded = $db->load_fasta($file,!$QUIET);
   warn "$file: $loaded records loaded\n";
 }
+
+if ($SUMMARY_STATS) {
+    warn "Building summary statistics for coverage histograms...\n";
+    $db->build_summary_statistics;
+}
