@@ -1,18 +1,14 @@
-#!/usr/bin/perl -w
-
-eval 'exec /usr/bin/perl -w -S $0 ${1+"$@"}'
-    if 0; # not running under some shell
-# $Id: mask_by_search.PLS 15088 2008-12-04 02:49:09Z bosborne $
+#!/usr/bin/perl 
 # Author:  Jason Stajich <jason-at-bioperl-dot-org>
 
 
 =head1 NAME
 
-mask_by_search - mask sequence(s) based on its alignment results
+bp_mask_by_search - mask sequence(s) based on its alignment results
 
 =head1 SYNOPSIS 
 
-  mask_by_search.pl -f blast genomefile blastfile.bls > maskedgenome.fa
+  bp_mask_by_search.pl -f blast genomefile blastfile.bls > maskedgenome.fa
 
 =head1 DESCRIPTION
 
@@ -63,6 +59,7 @@ Jason Stajich, jason-at-bioperl-dot-org.
 
 
 use strict;
+use warnings;
 use Bio::SeqIO;
 use Bio::SearchIO;
 use Getopt::Long;
