@@ -1,9 +1,7 @@
 #!/usr/bin/perl 
 
-eval 'exec /usr/bin/perl  -S $0 ${1+"$@"}'
-    if 0; # not running under some shell
-
 use strict;
+use warnings;
 use DBI;
 use Getopt::Long;
 use Bio::DB::GFF;
