@@ -2,7 +2,6 @@
 
 eval 'exec /usr/bin/perl  -S $0 ${1+"$@"}'
     if 0; # not running under some shell
-# $Id: bp_mrtrans.PLS 15088 2008-12-04 02:49:09Z bosborne $
 use strict;
 
 # Author:      Jason Stajich <jason-at-bioperl-dot-org>
@@ -45,6 +44,7 @@ Jason Stajich, jason-at-bioperl-dot-org
 =cut
 
 use strict;
+use warnings;
 use Bio::Align::Utilities qw(aa_to_dna_aln);
 use Bio::AlignIO;
 use Bio::SeqIO;
@@ -58,7 +58,7 @@ my ($iformat,$seqformat,$oformat,$seqdb,$input,$output) = ('clustalw','fasta',
 							   'phylip');
 my ($help,$usage);
 
-$usage = "usage: bp_mrtrans.pl -i prot_alignment -if align_format -o out_dna_align -of output_format -s cDNA_seqdb -sf cDNA_seqdb\n".
+$usage = "usage: bp_mrtrans.pl -i prot_alignment -if align_format -o out_dna_align -of output_format -s cDNA_seqdb -sf fasta\n".
 "defaults: -if clustalw
           -of phylip
           -sf fasta\n";
