@@ -1,23 +1,20 @@
-#!/usr/bin/perl -w
-
-eval 'exec /usr/bin/perl -w -S $0 ${1+"$@"}'
-    if 0; # not running under some shell
+#!/usr/bin/perl 
 
 =head1 NAME
 
-nexus2nh - convert nexus format trees (from PAUP* and MrBayes) to new hampshire
+bp_nexus2nh - convert nexus format trees (from PAUP* and MrBayes) to new hampshire
 
 =head1 SYNOPSIS
 
- nexus2nh file.nexus > file.nh
+ bp_nexus2nh file.nexus > file.nh
 
  # OR pipe in through STDIN
 
- cat file.nexus | nexus2nh > file.nh
+ cat file.nexus | bp_nexus2nh > file.nh
 
  # OR specify an output
 
- nexus2nh -o file.nh file.nexus
+ bp_nexus2nh -o file.nh file.nexus
 
 =head1 DESCRIPTION
 
@@ -27,6 +24,7 @@ Convert Nexus Tree files into Newick/New Hampshire format tree files.
 =cut
 
 use strict;
+use warnings;
 use Bio::TreeIO;
 use Getopt::Long;
 
