@@ -1,8 +1,4 @@
-#!/usr/bin/perl -w
-
-eval 'exec /usr/bin/perl -w -S $0 ${1+"$@"}'
-    if 0; # not running under some shell
-# $Id: bp_nrdb.PLS 15088 2008-12-04 02:49:09Z bosborne $
+#!/usr/bin/perl 
 
 # Author Jason Stajich <jason-at-bioperl-dot-org>
 # 
@@ -45,6 +41,7 @@ Jason Stajich, jason-at-bioperl-dot-org
 =cut
 
 use strict;
+use warnings;
 use Bio::SeqIO;
 use Getopt::Long;
 
