@@ -1,8 +1,4 @@
-#!/usr/bin/perl -w
-
-eval 'exec /usr/bin/perl -w -S $0 ${1+"$@"}'
-    if 0; # not running under some shell
-# $Id: oligo_count.PLS 15088 2008-12-04 02:49:09Z bosborne $
+#!/usr/bin/perl 
 #
 # oligomer_freq.pl
 # We use this to determine what primers are useful for frequent priming of
@@ -24,6 +20,7 @@ use Getopt::Long;
 #########################
 
 use strict;
+use warnings;
 
 my ($format, $infile, $help, $outfile, $oligomerlength) = ('fasta');
 GetOptions(
@@ -125,17 +122,19 @@ while (my $seq = $in->next_seq() ) {
     $seqnumber++;
 }
 
+my $OUTFILE;
 if ($outfile) {
-    open(OUTFILE, ">$outfile") or die "Can't open $outfile\n";
+    open $OUTFILE, '>', $outfile or die "Could not open file '$outfile': $!\n";
 } else {
-    open OUTFILE, '>-'; # STDOUT
+    open $OUTFILE, '>-'; # STDOUT
 }
-print OUTFILE "$seqnumber sequences analyzed\n";
-print OUTFILE "$oligocounts total $oligomerlength-mers counted\n";
-print OUTFILE "$oligomerlength-mer\tNumber\tFrequency\n";
+print $OUTFILE "$seqnumber sequences analyzed\n";
+print $OUTFILE "$oligocounts total $oligomerlength-mers counted\n";
+print $OUTFILE "$oligomerlength-mer\tNumber\tFrequency\n";
 foreach my $key (sort keys %oligos) {
-    print OUTFILE "$key\t$oligos{$key}\t", $oligos{$key}/$oligocounts, "\n";
+    print $OUTFILE "$key\t$oligos{$key}\t", $oligos{$key}/$oligocounts, "\n";
 }
+close $OUTFILE;
 
 if ($exception) {
     if ($exception == 1) {
@@ -193,11 +192,11 @@ __END__
 
 =head1 NAME
 
-oligo_count - oligo count and frequency
+bp_oligo_count - oligo count and frequency
 
 =head1 SYNOPSIS
 
-  Usage:  oligo_count [-h/--help] [-l/--length OLIGOLENGTH]
+  Usage:  bp_oligo_count [-h/--help] [-l/--length OLIGOLENGTH]
           [-f/--format SEQFORMAT] [-i/--in/-s/--sequence SEQFILE]
           [-o/--out OUTFILE]
 
@@ -235,7 +234,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via the
 web:
 
-  http://bugzilla.open-bio.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Charles C. Kim
 
