@@ -1,18 +1,18 @@
-#!/usr/bin/perl -w
+#!/usr/bin/perl 
 
-eval 'exec /usr/bin/perl -w -S $0 ${1+"$@"}'
+eval 'exec /usr/bin/perl  -S $0 ${1+"$@"}'
     if 0; # not running under some shell
 use strict;
-# $Id: pairwise_kaks.PLS 15088 2008-12-04 02:49:09Z bosborne $
+use warnings;
 # Author Jason Stajich <jason-at-bioperl-dot-org>
 
 =head1 NAME
 
-pairwise_kaks - script to calculate pairwise Ka,Ks for a set of sequences
+bp_pairwise_kaks - script to calculate pairwise Ka,Ks for a set of sequences
 
 =head1 SYNOPSIS
 
-pairwise_kaks.PLS -i t/data/worm_fam_2785.cdna [-f fasta/genbank/embl...] [-msa tcoffee/clustal] [-kaks yn00/codeml]
+bp_pairwise_kaks.PLS -i t/data/worm_fam_2785.cdna [-f fasta/genbank/embl...] [-msa tcoffee/clustal] [-kaks yn00/codeml]
 
 =head1 DESCRIPTION 
 
@@ -48,7 +48,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via the
 web:
 
-  http://bugzilla.open-bio.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR
 
