@@ -57,6 +57,7 @@ USAGE
 }
 
 use strict;
+use warnings;
 
 foreach (@ARGV) {
   $_ = "gunzip -c $_ |" if /\.gz$/;
@@ -104,20 +105,24 @@ sub dump_symbol {
 
 sub process_fasta {
   my $file = shift @ARGV;
-  open F,$file or die "Can't open $file: $!";
+  open my $F, '<', $file or die "Could not read file '$file': $!\n";
   print STDERR "Reading big FASTA file, please be patient...\n";
   my ($current_id,%lengths);
-  while (<F>) {
-    if (/^>(\S+)/) {
+  while (my $line = <$F>) {
+    if ($line =~ /^>(\S+)/) {
       $current_id = $1;
       next;
     }
     die "this doesn't look like a fasta file to me" unless $current_id;
-    chomp;
-    $lengths{$current_id} += length;
+    chomp $line;
+    $lengths{$current_id} += length $line;
   }
-  foreach (sort keys %lengths) {
-    print join("\t",$_,'arm','Component',1,$lengths{$_},'.','+','.',qq(Sequence "$_")),"\n";
+  close $F;
+
+  foreach my $id (sort keys %lengths) {
+    print join("\t", $id, 'arm', 'Component', 1, $lengths{$id},
+                     '.', '+', '.', qq(Sequence "$id")
+               ), "\n";
   }
 }
 
@@ -125,11 +130,11 @@ __END__
 
 =head1 NAME
 
-process_gadfly.pl - Massage Gadfly/FlyBase GFF files into a version suitable for the Generic Genome Browser
+bp_process_gadfly.pl - Massage Gadfly/FlyBase GFF files into a version suitable for the Generic Genome Browser
 
 =head1 SYNOPSIS
 
-  % process_gadfly.pl ./RELEASE2 > gadfly.gff
+  % bp_process_gadfly.pl ./RELEASE2 > gadfly.gff
 
 =head1 DESCRIPTION
 
@@ -148,7 +153,7 @@ you wish you can download the ZIP compressed versions of these files.
 Next run this script on the two files, indicating the name of the
 downloaded FASTA file first, followed by the gff file:
 
- % process_gadfly.pl na_whole-genome_genomic_dmel_RELEASE3.FASTA whole-genome_annotation-feature-region_dmel_RELEASE3.GFF > fly.gff
+ % bp_process_gadfly.pl na_whole-genome_genomic_dmel_RELEASE3.FASTA whole-genome_annotation-feature-region_dmel_RELEASE3.GFF > fly.gff
 
 The gadfly.gff file and the fasta file can now be loaded into a Bio::DB::GFF database
 using the following command:
