@@ -1,13 +1,10 @@
-#!/usr/bin/perl -w
+#!/usr/bin/perl 
 
-eval 'exec /usr/bin/perl -w -S $0 ${1+"$@"}'
-    if 0; # not running under some shell
-
-# $Id: process_sgd.PLS 15088 2008-12-04 02:49:09Z bosborne $
 # This script will convert from SGD format to GFF format
 # See http://db.yeastgenome.org/schema/Schema.html
 
 use strict;
+use warnings;
 
 # hard-coded length data that I couldn't get directly
 my %CHROMOSOMES = (I => 230_203,
@@ -87,11 +84,11 @@ __END__
 
 =head1 NAME
 
-process_sgd.pl - Massage SGD annotation flat files into a version suitable for the Generic Genome Browser
+bp_process_sgd.pl - Massage SGD annotation flat files into a version suitable for the Generic Genome Browser
 
 =head1 SYNOPSIS
 
-  % process_sgd.pl chromosomal_features.tab > yeast.gff
+  % bp_process_sgd.pl chromosomal_features.tab > yeast.gff
 
 =head1 DESCRIPTION
 
@@ -103,7 +100,7 @@ genome browser.
 To use this script, get the SGD chromosomal_features.tab file from the
 FTP site listed above, and run the following command:
 
-  % process_sgd.pl chromosomal_features.tab > yeast.gff
+  % bp_process_sgd.pl chromosomal_features.tab > yeast.gff
 
 The yeast.gff file can then be loaded into a Bio::DB::GFF database
 using the following command:
