@@ -1,10 +1,8 @@
 #!/usr/bin/perl 
 
-eval 'exec /usr/bin/perl  -S $0 ${1+"$@"}'
-    if 0; # not running under some shell
-
 use constant ACEDB => 'sace://aceserver.cshl.org:2005'; 
 use strict;
+use warnings;
 use Ace;
 
 my @framework = qw(mex-3 spe-15 lin-17 unc-11 dhc-1 unc-40 smg-5
@@ -175,11 +173,11 @@ __END__
 
 =head1 NAME
 
-process_wormbase.pl - Massage WormBase GFF files into a version suitable for the Generic Genome Browser
+bp_process_wormbase.pl - Massage WormBase GFF files into a version suitable for the Generic Genome Browser
 
 =head1 SYNOPSIS
 
-  % process_wormbase.pl ./WS61 > wormbase.gff
+  % bp_process_wormbase.pl ./WS61 > wormbase.gff
 
 =head1 DESCRIPTION
 
@@ -200,7 +198,7 @@ not need to uncompress the files.
 Then give that directory as the argument to this script and capture
 the script's output to a file:
 
-  % process_wormbase.pl ./WS61 > wormbase.gff
+  % bp_process_wormbase.pl ./WS61 > wormbase.gff
 
 It may take a while before you see output from this script, since it
 must first fetch gene and protein database from the remote AceDB
