@@ -1,10 +1,6 @@
-#!/usr/bin/perl -w
-
-eval 'exec /usr/bin/perl -w -S $0 ${1+"$@"}'
-    if 0; # not running under some shell
-# $Id: remote_blast.PLS 15088 2008-12-04 02:49:09Z bosborne $
+#!/usr/bin/perl 
 #
-# BioPerl module for remote_blast.pl
+# BioPerl module for bp_remote_blast.pl
 #
 # Revived by Evan Weaver for bioperl-1.5.1
 # 3/14/2006
@@ -16,6 +12,7 @@ eval 'exec /usr/bin/perl -w -S $0 ${1+"$@"}'
 # POD documentation - main docs after the code
 
 use strict;
+use warnings;
 use vars qw($USAGE);
 
 use Bio::Tools::Run::RemoteBlast;
@@ -128,7 +125,7 @@ while ( my @rids = $blastfactory->each_rid ) {
 __END__
 
 #
-# BioPerl module for remote_blast.pl
+# BioPerl module for bp_remote_blast.pl
 #
 # Cared for by Jason Stajich <jason-at-bioperl-dot-org>
 #
@@ -140,12 +137,12 @@ __END__
 
 =head1 NAME
 
-remote_blast.pl - script for submitting jobs to a remote blast server
+bp_remote_blast.pl - script for submitting jobs to a remote blast server
 (ncbi blast queue at this time)
 
 =head1 SYNOPSIS
 
-% remote_blast.pl -p blastp -d ecoli -e 1e-5 -i myseqs.fa
+% bp_remote_blast.pl -p blastp -d ecoli -e 1e-5 -i myseqs.fa
 
 =head1 DESCRIPTION
 
@@ -170,7 +167,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 the bugs and their resolution.  Bug reports can be submitted via the
 web:
 
-  http://bugzilla.open-bio.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Jason Stajich
 
