@@ -1,8 +1,4 @@
 #!/usr/bin/perl 
-
-eval 'exec /usr/bin/perl  -S $0 ${1+"$@"}'
-    if 0; # not running under some shell
-# $Id: revtrans-motif.PLS 16123 2009-09-17 12:57:27Z cjfields $
 use warnings;
 use strict;
 
@@ -17,7 +13,7 @@ use Pod::Usage;
 
 =head1 NAME
 
-revtrans-motif - Reverse translate a Profam-like protein motif
+bp_revtrans-motif - Reverse translate a Profam-like protein motif
 
 =head1 VERSION
 
@@ -31,15 +27,15 @@ our $VERSION = '0.01';
 
 From a file:
 
-    revtrans-motif.pl -i motifs.txt
+    bp_revtrans-motif.pl -i motifs.txt
 
 Using pipes:
 
-   revtrans-motif.pl < motifs.txt > output.txt
+   bp_revtrans-motif.pl < motifs.txt > output.txt
 
 Using interactively at the command prompt:
 
-   $ revtrans-motif.pl
+   $ bp_revtrans-motif.pl
    MAAEEL[VIKP]
    1.	ATGGCNGCNGARGARYTNVHN
    [^P]H(IW){2,3}
@@ -53,7 +49,7 @@ GetOptions( "h|help" => \$help, "i|infile:s" => \$infile );
 
 # Parse command line arguments.
 unless (defined $infile) { $infile = '-' };
-open( my $fh, "<$infile" ) or die "Couldn't open file $infile: $!\n";
+open my $fh, '<', $infile or die "Could not read file '$infile': $!\n";
 
 if ($help) { pod2usage(-verbose => 3) };
 
