@@ -1,19 +1,15 @@
-#!/usr/bin/perl -w
-
-eval 'exec /usr/bin/perl -w -S $0 ${1+"$@"}'
-    if 0; # not running under some shell
-# $Id: search2alnblocks.PLS 15088 2008-12-04 02:49:09Z bosborne $
+#!/usr/bin/perl 
 # Author:      Jason Stajich <jason-at-bioperl-dot-org>
 # Description: Turn SearchIO parseable report(s) into a set of Aligned blocks
 #
 
 =head1 NAME
 
-search2alnblocks - Turn SearchIO parseable reports(s) into a set of aligned blocks
+bp_search2alnblocks - Turn SearchIO parseable reports(s) into a set of aligned blocks
 
 =head1 SYNOPSIS
 
-  search2alnblocks --minid PERCENTID --minlen LEN --minevalue EVALUE file1.
+  bp_search2alnblocks --minid PERCENTID --minlen LEN --minevalue EVALUE file1.
   blast file2.blast ...> out.fas
 
 =head1 DESCRIPTION
@@ -52,6 +48,7 @@ Jason Stajich, jason-at-bioperl-dot-org.
 
 
 use strict;
+use warnings;
 
 use Bio::SearchIO;
 use Bio::AlignIO;
