@@ -1,15 +1,12 @@
-#!/usr/bin/perl -w
-
-eval 'exec /usr/bin/perl -w -S $0 ${1+"$@"}'
-    if 0; # not running under some shell
+#!/usr/bin/perl 
 
 =head1 NAME
 
-search2table - turn SearchIO parseable reports into tab delimited format like NCBI's -m 9 
+bp_search2table - turn SearchIO parseable reports into tab delimited format like NCBI's -m 9 
 
 =head1 SYNOPSIS
 
-  search2table -f fasta -i file.FASTA -o output.table
+  bp_search2table -f fasta -i file.FASTA -o output.table
 
 =head1 DESCRIPTION 
 
@@ -32,7 +29,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via
 email or the web:
 
-  http://bugzilla.open-bio.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR
 
@@ -41,6 +38,7 @@ email or the web:
 =cut
 
 use strict;
+use warnings;
 use Bio::SearchIO;
 use Getopt::Long;
 
@@ -59,7 +57,7 @@ my $in = Bio::SearchIO->new(-format => $format,
 			    -file   => $file);
 my $out;
 if( $output ) { 
-    open($out,">$output") || die "cannot open $output for writing";
+    open $out, '>', $output or die "Could not write file '$output': $!\n";
 } else { 
     $out = \*STDOUT;
 }
