@@ -1,20 +1,16 @@
-#!/usr/bin/perl -w
-
-eval 'exec /usr/bin/perl -w -S $0 ${1+"$@"}'
-    if 0; # not running under some shell
-# $Id: search2tribe.PLS 15088 2008-12-04 02:49:09Z bosborne $
+#!/usr/bin/perl 
 
 # Author:      Jason Stajich <jason-at-bioperl-dot-org>
 # Description: Turn SearchIO parseable report(s) into a TRIBE matrix
 #
 =head1 NAME
 
-search2tribe - Turn SearchIO parseable reports(s) into TRIBE matrix
+bp_search2tribe - Turn SearchIO parseable reports(s) into TRIBE matrix
 
 =head1 SYNOPSIS
 
 Usage:
-  search2tribe [-o outputfile] [-f reportformat] [-w/--weight] file1 file2 ..
+  bp_search2tribe [-o outputfile] [-f reportformat] [-w/--weight] file1 file2 ..
 
 =head1 DESCRIPTION
 
@@ -38,7 +34,7 @@ The options are:
 
 Additionally specify the filenames you want to process on the
 command-line.  If no files are specified then STDIN input is assumed.
-You specify this by doing: search2tribe E<lt> file1 file2 file3
+You specify this by doing: bp_search2tribe E<lt> file1 file2 file3
 
 =head1 AUTHOR
 
@@ -47,6 +43,7 @@ Jason Stajich, jason-at-bioperl-dot-org
 =cut
 
 use strict;
+use warnings;
 use Bio::SearchIO;
 use Bio::SearchIO::FastHitEventBuilder; # employ a speedup
 use Getopt::Long;
@@ -70,7 +67,7 @@ GetOptions(
 
 my $outfh;
 if( $output ) { 
-    open($outfh, ">$output") || die("Error opening output file $output. $!");
+    open $outfh, '>', $output or die "Could not write output file '$output': $!\n";
 } else {
     $outfh = *STDOUT;
 }
