@@ -1,19 +1,16 @@
-#!/usr/bin/perl -w
-
-eval 'exec /usr/bin/perl -w -S $0 ${1+"$@"}'
-    if 0; # not running under some shell
+#!/usr/bin/perl 
 
 =head1 NAME
 
-seq_length.pl - lists the number of bases and number of sequences in specified sequence database files
+bp_seq_length.pl - lists the number of bases and number of sequences in specified sequence database files
 
 =head1 SYNOPSIS
 
-seq_length.pl *.fa
+bp_seq_length.pl *.fa
 
 =head1 DESCRIPTION
 
-seq_length.pl will report the total number of residues and total number of individual sequences contained within a specified sequence database file.
+bp_seq_length.pl will report the total number of residues and total number of individual sequences contained within a specified sequence database file.
 
 =head1 OPTIONS
 
@@ -38,7 +35,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via the
 web:
 
-  http://bugzilla.open-bio.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Jason Stajich
 
@@ -47,6 +44,7 @@ Jason Stajich E<lt>jason@bioperl.orgE<gt>
 =cut
 
 use strict;
+use warnings;
 use Bio::SeqIO;
 use Getopt::Long;
 
