@@ -1,10 +1,10 @@
-#!/usr/bin/perl -w
+#!/usr/bin/perl 
 
-eval 'exec /usr/bin/perl -w -S $0 ${1+"$@"}'
+eval 'exec /usr/bin/perl  -S $0 ${1+"$@"}'
     if 0; # not running under some shell
-# $Id: seqconvert.PLS 15088 2008-12-04 02:49:09Z bosborne $
 
 use strict;
+use warnings;
 use Getopt::Long;
 use Bio::SeqIO;
 
@@ -45,13 +45,13 @@ __END__
 
 =head1 NAME
 
-seqconvert - generic BioPerl sequence format converter
+bp_seqconvert - generic BioPerl sequence format converter
 
 =head1 SYNOPSIS
 
-  seqconvert --from in-format --to out-format < file.in-format > file.out-format
+  bp_seqconvert --from in-format --to out-format < file.in-format > file.out-format
   # or
-  seqconvert -f in-format -t out-format < file.in-format > file.out-format
+  bp_seqconvert -f in-format -t out-format < file.in-format > file.out-format
 
 =head1 DESCRIPTION
 
@@ -79,7 +79,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via the
 web:
 
-  http://bugzilla.open-bio.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Philip Lijnzaad
 
