@@ -1,18 +1,14 @@
-#!/usr/bin/perl -w
-
-eval 'exec /usr/bin/perl -w -S $0 ${1+"$@"}'
-    if 0; # not running under some shell
-# $Id: seqretsplit.PLS 15088 2008-12-04 02:49:09Z bosborne $
+#!/usr/bin/perl 
 #
 =head1 NAME
 
-seqretsplit - split a sequence (or stream) into a single file per sequence
+bp_seqretsplit - split a sequence (or stream) into a single file per sequence
 
 =head1 SYNOPSIS
 
-  seqretsplit file1 file2 .. 
+  bp_seqretsplit file1 file2 .. 
   # or
-  seqretsplit < file1 
+  bp_seqretsplit < file1 
 
 =head1 DESCRIPTION 
 
@@ -40,7 +36,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via
 email or the web:
 
-http://bugzilla.open-bio.org/
+https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR
 
@@ -49,6 +45,7 @@ Jason Stajich E<lt>jason_AT_bioperl_DOT_orgE<gt>
 =cut
 
 use strict;
+use warnings;
 use Bio::SeqIO;
 my $in = Bio::SeqIO->new(-format => 'fasta',
 			 -fh   => \*ARGV);
