@@ -1,18 +1,15 @@
-#!/usr/bin/perl -w
-
-eval 'exec /usr/bin/perl -w -S $0 ${1+"$@"}'
-    if 0; # not running under some shell
+#!/usr/bin/perl 
 use strict;
-# $Id: split_seq.PLS 15120 2008-12-09 03:11:13Z cjfields $
+use warnings;
 
 =head1 NAME
 
-split_seq - splits a sequence into equal sized chunks with an optional
+bp_split_seq - splits a sequence into equal sized chunks with an optional
             overlapping range
 
 =head1 SYNOPSIS
 
-split_seq -c 10000 [-o 1000] [-i] -f seq.in
+bp_split_seq -c 10000 [-o 1000] [-i] -f seq.in
 
 =head1 DESCRIPTION 
 
@@ -47,7 +44,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via the
 web:
 
-  http://bugzilla.open-bio.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHORS
 
@@ -105,9 +102,10 @@ while (my $seq = $in->next_seq()) {
     mkdir("split", 0755) unless -e "split" and -d "split";
 
     # Creates the INDEX file if the option was given
+    my $FH;
     if ($opt_i) {
         $index_file = "$id.c$opt_c.o$offset.INDEX";
-        open(FH, ">", $index_file) or die("Unable to create file: $index_file ($!)");
+        open $FH, '>', $index_file or die "Could not write file '$index_file': $!\n";
     }
 
     # Loops through the sequence
@@ -128,7 +126,7 @@ while (my $seq = $in->next_seq()) {
         print "==> Sequence chunk:\t$seq_range\tstored in file:\tsplit/$id.faa\n";
 
         # Prints the current file name into the INDEX file if the option was given
-        print FH "split/$id.faa\n" if $opt_i;
+        print $FH "split/$id.faa\n" if $opt_i;
 
         # Decreases the $i value with the offset value
         $i -= $offset;
@@ -137,7 +135,7 @@ while (my $seq = $in->next_seq()) {
     # Closes the INDEX file if the option was given
     if ($opt_i) {
         print "==> INDEX stored in file:\t\t\t$index_file\n";
-        close(FH);
+        close $FH;
     }
 }
 
