@@ -1,6 +1,6 @@
-#!/usr/bin/perl -w
+#!/usr/bin/perl 
 
-eval 'exec /usr/bin/perl -w -S $0 ${1+"$@"}'
+eval 'exec /usr/bin/perl  -S $0 ${1+"$@"}'
     if 0; # not running under some shell
 # Author:  Jason Stajich <jason@bioperl.org>
 # Purpose: Retrieve the NCBI Taxa ID for organism(s)
@@ -11,6 +11,7 @@ eval 'exec /usr/bin/perl -w -S $0 ${1+"$@"}'
 use LWP::UserAgent;
 use XML::Twig;
 use strict;
+use warnings;
 use Getopt::Long;
 my $verbose = 0;
 my $plain   = 0;
@@ -53,11 +54,11 @@ unless( $plain  ) {
 
 =head1 NAME
 
-taxid4species - simple script which returns the NCBI Taxonomic id for a requested species
+bp_taxid4species - simple script which returns the NCBI Taxonomic id for a requested species
 
 =head1 SYNOPSIS
 
-taxid4species [-v] [-p] [-h] "Genus1 species1" "Genus2 species2"
+bp_taxid4species [-v] [-p] [-h] "Genus1 species1" "Genus2 species2"
 
 Options:
   -v   verbose
@@ -86,7 +87,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via the
 web:
 
-  http://bugzilla.open-bio.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR
 
