@@ -1,17 +1,14 @@
-#!/usr/bin/perl -w
-
-eval 'exec /usr/bin/perl -w -S $0 ${1+"$@"}'
-    if 0; # not running under some shell
+#!/usr/bin/perl 
 use strict;
-# $Id: translate_seq.PLS 15088 2008-12-04 02:49:09Z bosborne $
+use warnings;
 
 =head1 NAME
 
-translate_seq - translates a sequence
+bp_translate_seq - translates a sequence
 
 =head1 SYNOPSIS
 
-translate_seq E<lt> cdna_cds.fa E<gt> protein.fa
+bp_translate_seq E<lt> cdna_cds.fa E<gt> protein.fa
 
 =head1 DESCRIPTION 
 
@@ -34,7 +31,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via
 email or the web:
 
-  http://bugzilla.open-bio.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR
 
