@@ -1,23 +1,20 @@
-#!/usr/bin/perl -w
-
-eval 'exec /usr/bin/perl -w -S $0 ${1+"$@"}'
-    if 0; # not running under some shell
+#!/usr/bin/perl 
 
 =head1 NAME
 
-tree2pag - convert Bio::TreeIO parseable format trees to pagel format
+bp_tree2pag - convert Bio::TreeIO parseable format trees to pagel format
 
 =head1 SYNOPSIS
 
- tree2pag -if nexus -i file.nexus > file.pag
+ bp_tree2pag -if nexus -i file.nexus > file.pag
 
  # OR pipe in through STDIN, and use newick format instead
 
- cat file.newick | tree2pag -if newick > file.nh
+ cat file.newick | bp_tree2pag -if newick > file.nh
 
  # OR specify an output and input
 
- tree2pag -o file.pag -i file.newick
+ bp_tree2pag -o file.pag -i file.newick
 
 =head1 DESCRIPTION
 
@@ -28,6 +25,7 @@ so.  Also Pagel parsing is not yet available in bioperl.
 =cut
 
 use strict;
+use warnings;
 use Bio::TreeIO;
 use Getopt::Long;
 my ($iformat,$oformat) = ('newick', 'pag');
