@@ -1,25 +1,22 @@
-#!/usr/bin/perl -w
-
-eval 'exec /usr/bin/perl -w -S $0 ${1+"$@"}'
-    if 0; # not running under some shell
+#!/usr/bin/perl 
 use strict;
-# $Id: unflatten_seq.PLS 15088 2008-12-04 02:49:09Z bosborne $
+use warnings;
 # Author Chris Mungall <cjm-at-bioperl.org>
 
 =head1 NAME
 
-unflatten_seq - unflatten a genbank or genbank-style feature file into
+bp_unflatten_seq - unflatten a genbank or genbank-style feature file into
 a nested SeqFeature hierarchy
 
 =head1 SYNOPSIS
 
-  unflatten_seq.PLS -e 3 -gff ~/cvs/bioperl-live/t/data/AE003644_Adh-genomic.gb
+  bp_unflatten_seq.PLS -e 3 -gff ~/cvs/bioperl-live/t/data/AE003644_Adh-genomic.gb
 
-  unflatten_seq.PLS --detail ~/cvs/bioperl-live/t/data/AE003644_Adh-genomic.gb
+  bp_unflatten_seq.PLS --detail ~/cvs/bioperl-live/t/data/AE003644_Adh-genomic.gb
 
-  unflatten_seq.PLS -i foo.embl --from embl --to chadoxml -o out.chado.xml
+  bp_unflatten_seq.PLS -i foo.embl --from embl --to chadoxml -o out.chado.xml
 
-  unflatten_seq.PLS --notypemap --detail --to asciitree -ethresh 2 AE003644_Adh-genomic.gb
+  bp_unflatten_seq.PLS --notypemap --detail --to asciitree -ethresh 2 AE003644_Adh-genomic.gb
 
 =head1 DESCRIPTION 
 
@@ -159,7 +156,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via
 email or the web:
 
-  http://bugzilla.open-bio.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR
 
