@@ -12,14 +12,11 @@ See L<Bio::DB::GFF>
 
 # a simple oracle adaptor
 use strict;
-use Bio::DB::GFF::Adaptor::dbi;
 #use Bio::DB::GFF::Adaptor::dbi::mysql;
 #use Bio::DB::GFF::Adaptor::dbi::mysqlopt;
 use Bio::DB::GFF::Util::Binning;
 use Bio::DB::GFF::Util::Rearrange; # for rearrange()
-use vars qw(@ISA);
-#@ISA = qw(Bio::DB::GFF::Adaptor::dbi::mysqlopt);
-@ISA = qw(Bio::DB::GFF::Adaptor::dbi);
+use base qw(Bio::DB::GFF::Adaptor::dbi);
 
 use constant MAX_SEGMENT => 100_000_000;  # the largest a segment can get
 use constant DEFAULT_CHUNK => 2000;
@@ -495,8 +492,19 @@ index => {
 CREATE  INDEX fattribute_to_feature_fid ON fattribute_to_feature (fid,fattribute_id)
 }
 	   } # fattribute_to_feature indexes
-} # fattribute_to_feature  
+}, # fattribute_to_feature  
 
+       finterval_stats => {
+table=> q{
+CREATE TABLE "finterval_stats" (
+   "ftypeid"          integer DEFAULT '0' NOT NULL,
+   "fref"             VARCHAR(100) DEFAULT '' NOT NULL,
+   "fbin"             integer DEFAULT '0' NOT NULL,
+   "fcum_count"       integer DEFAULT '0' NOT NULL,
+   CONSTRAINT finterval_stats_pk PRIMARY KEY (ftypeid,fref,fbin)
+)
+} # finterval_stats table
+},# finterval_stats
 
 );
   return \%schema;
@@ -842,7 +850,7 @@ sub insert_sequence {
   my($id,$offset,$seq) = @_;
   my $sth = $self->{_insert_sequence}
     ||= $self->dbh->prepare_delayed('insert into fdna values (?,?,?)');
-  $sth->execute($id,$offset,$seq) or die $sth->errstr;
+  $sth->execute($id,$offset,$seq) or $self->throw($sth->errstr);
 }
 
 =head2 search_notes
@@ -861,6 +869,7 @@ Each row of the returned array is a arrayref containing the following fields:
   column 1     A Bio::DB::GFF::Featname object, suitable for passing to segment()
   column 2     The text of the note
   column 3     A relevance score.
+  column 4     A Bio::DB::GFF::Typename object
 
 =cut
 
@@ -868,28 +877,32 @@ sub search_notes {
   my $self = shift;
   my ($search_string,$limit) = @_;
 
+  $search_string =~ tr/*?//d;
+
   my @words  = $search_string =~ /(\w+)/g;
   my $regex  = join '|',@words;
   my @searches = map {"fattribute_value LIKE '%${_}%'"} @words;
   my $search   = join(' OR ',@searches);
 
   my $query = <<END;
-SELECT distinct gclass,gname,fattribute_value 
-  FROM fgroup,fattribute_to_feature,fdata
+SELECT distinct gclass,gname,fattribute_value,fmethod,fsource
+  FROM fgroup,fattribute_to_feature,fdata,ftype
   WHERE fgroup.gid=fdata.gid
      AND fdata.fid=fattribute_to_feature.fid
+     AND fdata.ftypeid=ftype.ftypeid
      AND ($search)
 END
 ;
 
   my $sth = $self->dbh->do_query($query);
   my @results;
-  while (my ($class,$name,$note) = $sth->fetchrow_array) {
+  while (my ($class,$name,$note,$method,$source) = $sth->fetchrow_array) {
      next unless $class && $name;    # sorry, ignore NULL objects
      my @matches = $note =~ /($regex)/g;
      my $relevance = 10*@matches;
      my $featname = Bio::DB::GFF::Featname->new($class=>$name);
-     push @results,[$featname,$note,$relevance];
+     my $type     = Bio::DB::GFF::Typename->new($method,$source);
+     push @results,[$featname,$note,$relevance,$type];
      last if $limit && @results >= $limit;
   }
   @results;
