@@ -146,19 +146,22 @@ use base 'Bio::DB::SeqFeature::Store::DBI::mysql';
 use Bio::DB::SeqFeature::Store::DBI::Iterator;
 use DBI qw(:sql_types);
 use Memoize;
-use Cwd 'abs_path';
+use Cwd qw(abs_path getcwd);
 use Bio::DB::GFF::Util::Rearrange 'rearrange';
 use Bio::SeqFeature::Lite;
 use File::Spec;
 use constant DEBUG=>0;
+use constant EXPERIMENTAL_COVERAGE=>1;
 
 # Using same limits as MySQL adaptor so I don't have to make something up.
 use constant MAX_INT =>  2_147_483_647;
 use constant MIN_INT => -2_147_483_648;
-use constant MAX_BIN =>  1_000_000_000;  # size of largest feature = 1 Gb
-use constant MIN_BIN =>  1000;           # smallest bin we'll make - on a 100 Mb chromosome, there'll be 100,000 of these
-use constant DEBUG_NONSPATIAL=>0;
+use constant SUMMARY_BIN_SIZE =>  1000;  # we checkpoint coverage this often, about 20 meg overhead per feature type on hg
+use constant USE_SPATIAL=>0;
 
+# The binning scheme places each feature into a bin.
+# Bins are variably sized as powers of two. For example,
+# there are 585 bins of size 2**17 (131072 bases)
 my (@BINS,%BINS);
 {
     @BINS = map {2**$_} (17, 20, 23, 26, 29);  # TO DO: experiment with different bin sizes
@@ -251,6 +254,10 @@ sub init {
     $dbh->do("PRAGMA synchronous = OFF;"); # makes writes much faster
     $dbh->do("PRAGMA temp_store = MEMORY;"); # less disk I/O; some speedup
     $dbh->do("PRAGMA cache_size = 20000;"); # less disk I/O; some speedup
+    # Keep track of database file location
+    my $cwd = getcwd;
+    my ($db_file) = ($dsn =~ m/(?:db(?:name)?|database)=(.+)$/);
+    $self->{dbh_file} = "$cwd/$db_file";
   }
   $self->{dbh}       = $dbh;
   $self->{is_temp}   = $is_temporary;
@@ -269,7 +276,7 @@ sub init {
 
 sub table_definitions {
   my $self = shift;
-  my $defs = 
+  my $defs =
       {
 	  feature => <<END,
 (
@@ -292,14 +299,14 @@ END
 	  typelist => <<END,
 (
   id  integer primary key autoincrement,
-  tag text    not null
+  tag text    not null collate nocase
 );
 create index index_typelist on typelist (tag);
 END
 	  name => <<END,
 (
   id           integer not null,
-  name         text    not null,
+  name         text    not null collate nocase,
   display_name integer default 0
 );
 create index index_name_id on name(id);
@@ -310,7 +317,7 @@ END
 (
   id              integer not null,
   attribute_id    integer not null,
-  attribute_value text
+  attribute_value text collate nocase
 );
 create index index_attribute_id    on attribute(attribute_id);
 create index index_attribute_value on attribute(attribute_value);
@@ -318,7 +325,7 @@ END
 
 	  attributelist => <<END,
 (
-  id  integer primary key autoincrement, 
+  id  integer primary key autoincrement,
   tag text    not null
 );
 create index index_attributelist_id  on attributelist(id);
@@ -329,7 +336,7 @@ END
   id    integer not null,
   child integer not null
 );
-create index index_parent2child_id_child on parent2child(id,child);
+create unique index index_parent2child_id_child on parent2child(id,child);
 END
 
 	  meta => <<END,
@@ -360,8 +367,19 @@ END
 create index index_feature_location on feature_location(seqid,bin,start,end);
 END
 
-  }
+    }
 
+  if (EXPERIMENTAL_COVERAGE) {
+    $defs->{interval_stats} = <<END;
+(
+   typeid            integer not null,
+   seqid             integer not null,
+   bin               integer not null,
+   cum_count         integer not null,
+   unique(typeid,seqid,bin)
+);
+END
+  }
   return $defs;
 }
 
@@ -385,10 +403,7 @@ sub _create_spatial_index{
     my $dbh   = $self->dbh;
     local $dbh->{PrintError} = 0;
     $dbh->do("DROP TABLE IF EXISTS feature_index"); # spatial index
-    if (DEBUG_NONSPATIAL) {
-	warn "DELIBERATELY BREAKING RTREE FUNCTIONALITY";
-	$dbh->do("CREATE VIRTUAL TABLE feature_index USING BTREE(id,seqid,bin,start,end)");
-    } else {
+    if (USE_SPATIAL) {
 	$dbh->do("CREATE VIRTUAL TABLE feature_index USING RTREE(id,seqid,bin,start,end)");
     }
 }
@@ -406,13 +421,14 @@ sub _finish_bulk_update {
   my $dbh  = $self->dbh;
   my $dir = $self->{dumpdir} || '.';
 
-  $dbh->begin_work; # making this a transaction greatly improves performance
-  
+  $self->begin_work; # making this a transaction greatly improves performance
+
   for my $table ('feature', $self->index_tables) {
     my $fh = $self->dump_filehandle($table);
     my $path = $self->dump_path($table);
     $fh->close;
-    open($fh, $path);
+
+    open $fh, '<', $path or $self->throw("Could not read file '$path': $!");
     my $qualified_table = $self->_qualify($table);
 
     my $sth;
@@ -436,7 +452,7 @@ sub _finish_bulk_update {
 	} elsif ($table =~ /$feature_index$/) {
 	    $sth = $dbh->prepare(
 		$self->_has_spatial_index ?"REPLACE INTO $qualified_table VALUES (?,?,?,?,?)"
-		                          :"REPLACE INTO $qualified_table VALUES (?,?,?,?,?)"
+		                          :"REPLACE INTO $qualified_table (id,seqid,bin,start,end) VALUES (?,?,?,?,?)"
 		);
 	} else { # attribute or name
 	    $sth = $dbh->prepare("REPLACE INTO $qualified_table VALUES (?,?,?)");
@@ -450,7 +466,7 @@ sub _finish_bulk_update {
     $fh->close();
     unlink $path;
   }
-  $dbh->commit; # commit the transaction
+  $self->commit; # commit the transaction
   delete $self->{bulk_update_in_progress};
   delete $self->{filehandles};
 }
@@ -461,6 +477,21 @@ sub index_tables {
     return (@t,$self->_feature_index_table);
 }
 
+sub _enable_keys  { }  # nullop
+sub _disable_keys { }  # nullop
+
+sub _fetch_indexed_features_sql {
+    my $self = shift;
+    my $location_table       = $self->_qualify('feature_location');
+    my $feature_table        = $self->_qualify('feature');
+    return <<END;
+    SELECT typeid,seqid,start-1,end
+  FROM $location_table as l,$feature_table as f
+ WHERE l.id=f.id AND f.\"indexed\"=1
+  ORDER BY typeid,seqid,start
+END
+}
+
 ###
 # get primary sequence between start and end
 #
@@ -500,7 +531,7 @@ END
   while (my($frag,$offset) = $sth->fetchrow_array) {
     substr($frag,0,$start-$offset) = '' if defined $start && $start > $offset;
     $seq .= $frag;
-  }  
+  }
   substr($seq,$end-$start+1) = '' if defined $end && $end-$start+1 < length($seq);
   if ($reversed) {
     $seq = reverse $seq;
@@ -593,7 +624,7 @@ sub _features {
     push @group,$group if $group;
     push @args,@a;
   }
-  
+
   if (defined($sources)) {
     my @sources = ref($sources) eq 'ARRAY' ? @{$sources} : ($sources);
     if (defined($types)) {
@@ -681,7 +712,7 @@ sub _location_sql {
 
   # the additional join on the location_list table badly impacts performance
   # so we build a copy of the table in memory
-  my $seqid = $self->_locationid($seq_id) || 0; # zero is an invalid primary ID, so will return empty
+  my $seqid = $self->_locationid_nocreate($seq_id) || 0; # zero is an invalid primary ID, so will return empty
 
   my $feature_index = $self->_feature_index_table;
   my $from  = "$feature_index as fi";
@@ -719,14 +750,14 @@ sub _location_sql {
       AND   $location.id=fi.id
       AND   $range
 END
-;	  
+;
   my $group = '';
-      
+
   my @args  = ($seqid,@range_args);
   return ($from,$where,$group,@args);
 }
 
-sub _feature_index_table          {  
+sub _feature_index_table          {
     my $self = shift;
     return $self->_has_spatial_index ? $self->_qualify('feature_index')
                                      : $self->_qualify('feature_location') }
@@ -740,7 +771,7 @@ sub _name_sql {
   my $from  = "$name_table as n";
   my ($match,$string) = $self->_match_sql($name);
 
-  my $where = "n.id=$join AND lower(n.name) $match";
+  my $where = "n.id=$join AND n.name $match COLLATE NOCASE";
   $where   .= " AND n.display_name>0" unless $allow_aliases;
   return ($from,$where,'',$string);
 }
@@ -766,7 +797,7 @@ sub _search_attributes {
   # CROSS JOIN disables SQLite's table reordering optimization
   my $sql = <<END;
 SELECT name,attribute_value,tl.tag,n.id
-  FROM $attributelist_table        AS al 
+  FROM $attributelist_table        AS al
        CROSS JOIN $attribute_table AS a  ON al.id = a.attribute_id
        CROSS JOIN $name_table      AS n  ON n.id = a.id
        CROSS JOIN $type_table      AS t  ON t.id = n.id
@@ -804,8 +835,8 @@ sub _match_sql {
     $match = "LIKE ?";
     $string  = $name;
   } else {
-    $match = "= lower(?)";
-    $string  = lc($name);
+    $match = "= ? COLLATE NOCASE";
+    $string  = $name;
   }
   return ($match,$string);
 }
@@ -856,8 +887,8 @@ sub _types_sql {
       ($primary_tag,$source_tag) = split ':',$type,2;
     }
 
-    if (defined $source_tag) {
-      push @matches,"lower(tl.tag)=lower(?)";
+    if (length $source_tag) {
+      push @matches,"tl.tag=? COLLATE NOCASE";
       push @args,"$primary_tag:$source_tag";
     } else {
       push @matches,"tl.tag LIKE ?";
@@ -896,7 +927,7 @@ sub replace {
 REPLACE INTO $features (id,object,"indexed",strand,typeid) VALUES (?,?,?,?,?)
 END
 
-  my ($seqid,$start,$end,$strand,$bin) = $index_flag ? $self->_get_location_and_bin($object) : (undef)x5;
+  my ($seqid,$start,$end,$strand,$bin) = $index_flag ? $self->_get_location_and_bin($object) : (undef)x6;
 
   my $primary_tag = $object->primary_tag;
   my $source_tag  = $object->source_tag || '';
@@ -926,9 +957,9 @@ sub bulk_replace {
     my $self       = shift;
     my $index_flag = shift || undef;
     my @objects    = @_;
-    
+
     my $features = $self->_feature_table;
-    
+
     my @insert_values;
     foreach my $object (@objects) {
         my $id = $object->primary_id;
@@ -937,17 +968,17 @@ sub bulk_replace {
         my $source_tag  = $object->source_tag || '';
         $primary_tag    .= ":$source_tag";
         my $typeid   = $self->_typeid($primary_tag,1);
-        
+
         push(@insert_values, ($id,0,$index_flag||0,$strand,$typeid));
     }
-    
+
     my @value_blocks;
     for (1..@objects) {
         push(@value_blocks, '(?,?,?,?,?)');
     }
     my $value_blocks = join(',', @value_blocks);
     my $sql = qq{REPLACE INTO $features (id,object,"indexed",strand,typeid) VALUES $value_blocks};
-    
+
     my $sth = $self->_prepare($sql);
     $sth->execute(@insert_values) or $self->throw($sth->errstr);
 }
@@ -955,13 +986,15 @@ sub bulk_replace {
 sub _get_location_and_bin {
     my $self = shift;
     my $obj  = shift;
-    my $seqid   = $self->_locationid($obj->seq_id);
+    my $seqid   = $self->_locationid($obj->seq_id||'');
     my $start   = $obj->start;
     my $end     = $obj->end;
     my $strand  = $obj->strand;
     return ($seqid,$start,$end,$strand,$self->calculate_bin($start,$end));
 }
 
+
+
 ###
 # Insert one Bio::SeqFeatureI into database. primary_id must be undef
 #
@@ -983,23 +1016,50 @@ END
   $self->flag_for_indexing($dbh->func('last_insert_rowid')) if $self->{bulk_update_in_progress};
 }
 
-=head2 types
+=head2 toplevel_types
 
- Title   : types
- Usage   : @type_list = $db->types
- Function: Get all the types in the database
+ Title   : toplevel_types
+ Usage   : @type_list = $db->toplevel_types
+ Function: Get the toplevel types in the database
  Returns : array of Bio::DB::GFF::Typename objects
  Args    : none
  Status  : public
 
+This is similar to types() but only returns the types of
+INDEXED (toplevel) features.
+
 =cut
 
+sub toplevel_types {
+    my $self = shift;
+    eval "require Bio::DB::GFF::Typename"
+	unless Bio::DB::GFF::Typename->can('new');
+    my $typelist_table      = $self->_typelist_table;
+    my $feature_table       = $self->_feature_table;
+    my $sql = <<END;
+SELECT distinct(tag) from $typelist_table as tl,$feature_table as f
+ WHERE tl.id=f.typeid
+   AND f."indexed"=1
+END
+;
+    $self->_print_query($sql) if DEBUG || $self->debug;
+    my $sth = $self->_prepare($sql);
+    $sth->execute() or $self->throw($sth->errstr);
+
+    my @results;
+    while (my($tag) = $sth->fetchrow_array) {
+	push @results,Bio::DB::GFF::Typename->new($tag);
+    }
+    $sth->finish;
+    return @results;
+}
+
 sub _genericid {
   my $self = shift;
   my ($table,$namefield,$name,$add_if_missing) = @_;
   my $qualified_table = $self->_qualify($table);
   my $sth = $self->_prepare(<<END);
-SELECT id FROM $qualified_table WHERE $namefield=?
+SELECT id FROM $qualified_table WHERE $namefield=? COLLATE NOCASE
 END
   $sth->execute($name) or die $sth->errstr;
   my ($id) = $sth->fetchrow_array;
@@ -1062,6 +1122,23 @@ sub _dump_update_name_index {
   print $fh join("\t",$id,$_,0),"\n" foreach @$aliases;
 }
 
+sub _update_name_index {
+  my $self = shift;
+  my ($obj,$id) = @_;
+  my $name = $self->_name_table;
+  my $primary_id = $obj->primary_id;
+
+  $self->_delete_index($name,$id);
+  my ($names,$aliases) = $self->feature_names($obj);
+
+  my $sth = $self->_prepare("INSERT INTO $name (id,name,display_name) VALUES (?,?,?)");
+
+  $sth->execute($id,$_,1) or $self->throw($sth->errstr)   foreach @$names;
+  $sth->execute($id,$_,0) or $self->throw($sth->errstr) foreach @$aliases;
+  $sth->finish;
+}
+
+
 sub _dump_update_attribute_index {
   my $self = shift;
   my ($obj,$id) = @_;
@@ -1106,7 +1183,7 @@ sub _update_location_index {
 	$sql    = "INSERT INTO $table (id,seqid,bin,start,end) values (?,?,?,?,?)";
 	@args   = ($id,$seqid,$bin,$start,$end);
     }
-	    
+
     my $sth  = $self->_prepare($sql);
     $sth->execute(@args);
     $sth->finish;
@@ -1124,6 +1201,15 @@ sub _dump_update_location_index {
     print $fh join("\t",@args),"\n";
 }
 
+sub DESTROY {
+    my $self = shift;
+    # Remove filehandles, so temporal files can be properly deleted
+    if (%DBI::installed_drh) {
+	DBI->disconnect_all;
+	%DBI::installed_drh = ();
+    }
+    undef $self->{dbh};
+}
 
 1;
 
@@ -1133,8 +1219,11 @@ Nathan Weeks - Nathan.Weeks@ars.usda.gov
 
 Copyright (c) 2009 Nathan Weeks
 
+Modified 2010 to support cumulative statistics by Lincoln Stein
+<lincoln.stein@gmail.com>.
+
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+it under the same terms as Perl itself. See the Bioperl license for
+more details.
 
 =cut
-
