@@ -1,5 +1,3 @@
-# $Id: SeqIO.pm 16090 2009-09-15 21:57:56Z cjfields $
-#
 # BioPerl module for Bio::SeqIO
 #
 # Please direct questions and support issues to <bioperl-l@bioperl.org> 
@@ -30,7 +28,7 @@ Bio::SeqIO - Handler for SeqIO Formats
                            -format => 'EMBL');
 
     while ( my $seq = $in->next_seq() ) {
-	    $out->write_seq($seq);
+        $out->write_seq($seq);
     }
 
   # Now, to actually get at the sequence object, use the standard Bio::Seq
@@ -100,7 +98,7 @@ operations to read and write sequence objects:
     # read from standard input or the input filenames
 
     while ( $seq = <$stream> ) {
-	  # do something with $seq
+        # do something with $seq
     }
 
 and
@@ -110,15 +108,15 @@ and
 This makes the simplest ever reformatter
 
     #!/usr/bin/perl
-
-    $format1 = shift;
-    $format2 = shift || die
+    use strict;
+    my $format1 = shift;
+    my $format2 = shift || die
        "Usage: reformat format1 format2 < input > output";
 
     use Bio::SeqIO;
 
-    $in  = Bio::SeqIO->newFh(-format => $format1, -fh => \*ARGV );
-    $out = Bio::SeqIO->newFh(-format => $format2 );
+    my $in  = Bio::SeqIO->newFh(-format => $format1, -fh => \*ARGV );
+    my $out = Bio::SeqIO->newFh(-format => $format2 );
     # Note: you might want to quote -format to keep older
     # perl's from complaining.
 
@@ -129,13 +127,14 @@ This makes the simplest ever reformatter
 
 =head2 Bio::SeqIO-E<gt>new()
 
-   $seqIO = Bio::SeqIO->new(-file => 'filename',   -format=>$format);
-   $seqIO = Bio::SeqIO->new(-fh   => \*FILEHANDLE, -format=>$format);
+   $seqIO = Bio::SeqIO->new(-file   => 'seqs.fasta', -format => $format);
+   $seqIO = Bio::SeqIO->new(-fh     => \*FILEHANDLE, -format => $format);
+   $seqIO = Bio::SeqIO->new(-string => $string     , -format => $format);
    $seqIO = Bio::SeqIO->new(-format => $format);
 
-The new() class method constructs a new Bio::SeqIO object.  The
-returned object can be used to retrieve or print Seq objects. new()
-accepts the following parameters:
+The new() class method constructs a new Bio::SeqIO object. The returned object
+can be used to retrieve or print Seq objects. new() accepts the following
+parameters:
 
 =over 5
 
@@ -153,16 +152,10 @@ conventions apply:
 
 =item -fh
 
-You may provide new() with a previously-opened filehandle.  For
+You may use new() with a opened filehandle, provided as a glob reference. For
 example, to read from STDIN:
 
-   $seqIO = Bio::SeqIO->new(-fh => \*STDIN);
-
-Note that you must pass filehandles as references to globs.
-
-If neither a filehandle nor a filename is specified, then the module
-will read from the @ARGV array or STDIN, using the familiar E<lt>E<gt>
-semantics.
+   my $seqIO = Bio::SeqIO->new(-fh => \*STDIN);
 
 A string filehandle is handy if you want to modify the output in the
 memory, before printing it out. The following program reads in EMBL
@@ -171,13 +164,13 @@ some HTML tags:
 
   use Bio::SeqIO;
   use IO::String;
-  my $in  = Bio::SeqIO->new(-file => "emblfile",
-  		            -format => 'EMBL');
+  my $in = Bio::SeqIO->new(-file => "emblfile",
+                           -format => 'EMBL');
   while ( my $seq = $in->next_seq() ) {
       # the output handle is reset for every file
       my $stringio = IO::String->new($string);
       my $out = Bio::SeqIO->new(-fh => $stringio,
-  			        -format => 'fasta');
+                                -format => 'fasta');
       # output goes into $string
       $out->write_seq($seq);
       # modify $string
@@ -186,6 +179,13 @@ some HTML tags:
       print $string;
   }
 
+=item -string
+
+A string to read the sequences from. For example:
+
+   my $string = ">seq1\nACGCTAGCTAGC\n";
+   my $seqIO = Bio::SeqIO->new(-string => $string);
+
 =item -format
 
 Specify the format of the file.  Supported formats include fasta,
@@ -229,6 +229,17 @@ evaluates as defined but false:
                            -flush  => 0); # go as fast as we can!
   while($seq = $gb->next_seq) { $fa->write_seq($seq) }
 
+=item -seqfactory
+
+Provide a Bio::Factory::SequenceFactoryI object. See the sequence_factory() method.
+
+=item -locfactory
+
+Provide a Bio::Factory::LocationFactoryI object. See the location_factory() method.
+
+=item -objbuilder
+
+Provide a Bio::Factory::ObjectBuilderI object. See the object_builder() method.
 
 =back
 
@@ -295,7 +306,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 the bugs and their resolution.  Bug reports can be submitted via the
 web:
 
-  http://bugzilla.open-bio.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Ewan Birney, Lincoln Stein
 
@@ -314,34 +325,38 @@ methods. Internal methods are usually preceded with a _
 package Bio::SeqIO;
 
 use strict;
+use warnings;
 
 use Bio::Factory::FTLocationFactory;
 use Bio::Seq::SeqBuilder;
 use Bio::Tools::GuessSeqFormat;
 use Symbol;
 
-use base qw(Bio::Root::Root Bio::Root::IO Bio::Factory::SequenceStreamI);
+use parent qw(Bio::Root::Root Bio::Root::IO Bio::Factory::SequenceStreamI);
 
 my %valid_alphabet_cache;
 
+
 =head2 new
 
  Title   : new
- Usage   : $stream = Bio::SeqIO->new(-file => $filename,
-                                     -format => 'Format')
+ Usage   : $stream = Bio::SeqIO->new(-file => 'sequences.fasta',
+                                     -format => 'fasta');
  Function: Returns a new sequence stream
  Returns : A Bio::SeqIO stream initialised with the appropriate format
- Args    : Named parameters:
-             -file => $filename
-             -fh => filehandle to attach to
-             -format => format
+ Args    : Named parameters indicating where to read the sequences from or to
+           write them to:
+             -file   => filename, OR
+             -fh     => filehandle to attach to, OR
+             -string => string
 
-           Additional arguments may be used to set factories and
-           builders involved in the sequence object creation. None of
-           these must be provided, they all have reasonable defaults.
-             -seqfactory   the Bio::Factory::SequenceFactoryI object
-             -locfactory   the Bio::Factory::LocationFactoryI object
-             -objbuilder   the Bio::Factory::ObjectBuilderI object
+           Additional arguments, all with reasonable defaults:
+             -format     => format of the sequences, usually auto-detected
+             -alphabet   => 'dna', 'rna', or 'protein'
+             -flush      => 0 or 1 (default: flush filehandles after each write)
+             -seqfactory => sequence factory
+             -locfactory => location factory
+             -objbuilder => object builder
 
 See L<Bio::SeqIO::Handler>
 
@@ -350,52 +365,69 @@ See L<Bio::SeqIO::Handler>
 my $entry = 0;
 
 sub new {
-	my ($caller,@args) = @_;
-	my $class = ref($caller) || $caller;
+    my ($caller, @args) = @_;
+    my $class = ref($caller) || $caller;
 
-	# or do we want to call SUPER on an object if $caller is an
-	# object?
-	if( $class =~ /Bio::SeqIO::(\S+)/ ) {
-		my ($self) = $class->SUPER::new(@args);
-		$self->_initialize(@args);
-		return $self;
-	} else {
+    # or do we want to call SUPER on an object if $caller is an
+    # object?
+    if( $class =~ /Bio::SeqIO::(\S+)/ ) {
+        my ($self) = $class->SUPER::new(@args);
+        $self->_initialize(@args);
+        return $self;
+    } else {
+        my %params = @args;
+        @params{ map { lc $_ } keys %params } = values %params; # lowercase keys
 
-		my %param = @args;
-		@param{ map { lc $_ } keys %param } = values %param; # lowercase keys
+        unless( defined $params{-file} ||
+                defined $params{-fh}   ||
+                defined $params{-string} ) {
+            $class->throw("file argument provided, but with an undefined value") 
+                if exists $params{'-file'};
+            $class->throw("fh argument provided, but with an undefined value") 
+                if exists $params{'-fh'};
+            $class->throw("string argument provided, but with an undefined value") 
+                if exists($params{'-string'});
+            # $class->throw("No file, fh, or string argument provided"); # neither defined
+        }
 
-	if (!defined($param{-file}) && !defined($param{-fh})) {
-	  $class->throw("file argument provided, but with an undefined value") if exists($param{'-file'});
-	  $class->throw("fh argument provided, but with an undefined value") if (exists($param{'-fh'}));
-	}
+        # Determine or guess sequence format and variant
+        my $format = $params{'-format'};
+        if (! $format ) {
+            if ($params{-file}) {
+                # Guess from filename extension, and then from file content
+                $format = $class->_guess_format( $params{-file} ) ||
+                          Bio::Tools::GuessSeqFormat->new(-file => $params{-file}  )->guess;
+            } elsif ($params{-fh}) {
+                # Guess from filehandle content
+                $format = Bio::Tools::GuessSeqFormat->new(-fh   => $params{-fh}    )->guess;
+            } elsif ($params{-string}) {
+                # Guess from string content
+                $format = Bio::Tools::GuessSeqFormat->new(-text => $params{-string})->guess;
+            }
+        }
 
-	my $format = $param{'-format'} ||
-	    $class->_guess_format( $param{-file} || $ARGV[0] );
-        
-	if( ! $format ) {
-	    if ($param{-file}) {
-		$format = Bio::Tools::GuessSeqFormat->new(-file => $param{-file}||$ARGV[0] )->guess;
-	    } elsif ($param{-fh}) {
-		$format = Bio::Tools::GuessSeqFormat->new(-fh => $param{-fh}||$ARGV[0] )->guess;
-	    }
-	}
-	$format = "\L$format";	# normalize capitalization to lower case
-    $class->throw("Unknown format given or could not determine it [$format]")
-        unless $format;
-    if ($format =~ /-/) {
-        ($format, my $variant) = split('-', $format, 2);
-        push @args, (-variant => $variant);
-    }
-	return unless( $class->_load_format_module($format) );
-	return "Bio::SeqIO::$format"->new(@args);
+        # changed 1-3-11; no need to print out an empty string (only way this
+        # exception is triggered) - cjfields
+        $class->throw("Could not guess format from file, filehandle or string")
+            if not $format;
+        $format = "\L$format";  # normalize capitalization to lower case
+
+        if ($format =~ /-/) {
+            ($format, my $variant) = split('-', $format, 2);
+            $params{-variant} = $variant;
+        }
+
+        return unless( $class->_load_format_module($format) );
+        return "Bio::SeqIO::$format"->new(%params);
     }
 }
 
+
 =head2 newFh
 
  Title   : newFh
  Usage   : $fh = Bio::SeqIO->newFh(-file=>$filename,-format=>'Format')
- Function: does a new() followed by an fh()
+ Function: Does a new() followed by an fh()
  Example : $fh = Bio::SeqIO->newFh(-file=>$filename,-format=>'Format')
            $sequence = <$fh>;   # read a sequence object
            print $fh $sequence; # write a sequence object
@@ -407,16 +439,17 @@ See L<Bio::SeqIO::Fh>
 =cut
 
 sub newFh {
-  my $class = shift;
-  return unless my $self = $class->new(@_);
-  return $self->fh;
+    my $class = shift;
+    return unless my $self = $class->new(@_);
+    return $self->fh;
 }
 
+
 =head2 fh
 
  Title   : fh
  Usage   : $obj->fh
- Function:
+ Function: Get or set the IO filehandle
  Example : $fh = $obj->fh;      # make a tied filehandle
            $sequence = <$fh>;   # read a sequence object
            print $fh $sequence; # write a sequence object
@@ -425,48 +458,48 @@ sub newFh {
 
 =cut
 
-
 sub fh {
-  my $self = shift;
-  my $class = ref($self) || $self;
-  my $s = Symbol::gensym;
-  tie $$s,$class,$self;
-  return $s;
+    my $self = shift;
+    my $class = ref($self) || $self;
+    my $s = Symbol::gensym;
+    tie $$s,$class,$self;
+    return $s;
 }
 
+
 # _initialize is chained for all SeqIO classes
 
 sub _initialize {
-	my($self, @args) = @_;
+    my($self, @args) = @_;
 
-	# flush is initialized by the Root::IO init
+    # flush is initialized by the Root::IO init
 
-	my ($seqfact,$locfact,$objbuilder, $alphabet) =
-	  $self->_rearrange([qw(SEQFACTORY
-			      LOCFACTORY
-			      OBJBUILDER
-                  ALPHABET)
-							  ], @args);
+    my ($seqfact,$locfact,$objbuilder, $alphabet) =
+        $self->_rearrange([qw(SEQFACTORY
+                              LOCFACTORY
+                              OBJBUILDER
+                              ALPHABET)
+                                         ], @args);
 
-	$locfact = Bio::Factory::FTLocationFactory->new(-verbose => $self->verbose)
-	  if ! $locfact;
-	$objbuilder = Bio::Seq::SeqBuilder->new(-verbose => $self->verbose)
-	  unless $objbuilder;
-	$self->sequence_builder($objbuilder);
-	$self->location_factory($locfact);
+    $locfact = Bio::Factory::FTLocationFactory->new(-verbose => $self->verbose)
+        if ! $locfact;
+    $objbuilder = Bio::Seq::SeqBuilder->new(-verbose => $self->verbose)
+        unless $objbuilder;
+    $self->sequence_builder($objbuilder);
+    $self->location_factory($locfact);
 
-	# note that this should come last because it propagates the sequence
-	# factory to the sequence builder
-	$seqfact && $self->sequence_factory($seqfact);
+    # note that this should come last because it propagates the sequence
+    # factory to the sequence builder
+    $seqfact && $self->sequence_factory($seqfact);
         
     #bug 2160
     $alphabet && $self->alphabet($alphabet);
 
-
-	# initialize the IO part
-	$self->_initialize_io(@args);
+    # initialize the IO part
+    $self->_initialize_io(@args);
 }
 
+
 =head2 next_seq
 
  Title   : next_seq
@@ -499,6 +532,7 @@ sub next_seq {
    $self->throw("Sorry, you cannot read from a generic Bio::SeqIO object.");
 }
 
+
 =head2 write_seq
 
  Title   : write_seq
@@ -515,6 +549,19 @@ sub write_seq {
 }
 
 
+=head2 format
+
+ Title   : format
+ Usage   : $format = $stream->format()
+ Function: Get the sequence format
+ Returns : sequence format, e.g. fasta, fastq
+ Args    : none
+
+=cut
+
+# format() method inherited from Bio::Root::IO
+
+
 =head2 alphabet
 
  Title   : alphabet
@@ -531,25 +578,26 @@ sub alphabet {
    my ($self, $value) = @_;
 
    if ( defined $value) {
-		$value = lc $value;
-		unless ($valid_alphabet_cache{$value}) {
-			# instead of hard-coding the allowed values once more, we check by
-			# creating a dummy sequence object
-			eval {
-				require Bio::PrimarySeq;
-				my $seq = Bio::PrimarySeq->new('-verbose' => $self->verbose,
-														 '-alphabet' => $value);
-			};
-			if ($@) {
-				$self->throw("Invalid alphabet: $value\n. See Bio::PrimarySeq for allowed values.");
-			}
-			$valid_alphabet_cache{$value} = 1;
-		}
-		$self->{'alphabet'} = $value;
+        $value = lc $value;
+        unless ($valid_alphabet_cache{$value}) {
+            # instead of hard-coding the allowed values once more, we check by
+            # creating a dummy sequence object
+            eval {
+                require Bio::PrimarySeq;
+                my $seq = Bio::PrimarySeq->new( -verbose  => $self->verbose,
+                                                -alphabet => $value          );
+            };
+            if ($@) {
+                $self->throw("Invalid alphabet: $value\n. See Bio::PrimarySeq for allowed values.");
+            }
+            $valid_alphabet_cache{$value} = 1;
+        }
+        $self->{'alphabet'} = $value;
    }
    return $self->{'alphabet'};
 }
 
+
 =head2 _load_format_module
 
  Title   : _load_format_module
@@ -562,25 +610,26 @@ sub alphabet {
 =cut
 
 sub _load_format_module {
-	my ($self, $format) = @_;
-	my $module = "Bio::SeqIO::" . $format;
-	my $ok;
+    my ($self, $format) = @_;
+    my $module = "Bio::SeqIO::" . $format;
+    my $ok;
 
-	eval {
-		$ok = $self->_load_module($module);
-	};
-	if ( $@ ) {
-		print STDERR <<END;
+    eval {
+        $ok = $self->_load_module($module);
+    };
+    if ( $@ ) {
+        print STDERR <<END;
 $self: $format cannot be found
 Exception $@
 For more information about the SeqIO system please see the SeqIO docs.
 This includes ways of checking for formats at compile time, not run time
 END
-		;
-	}
-	return $ok;
+        ;
+    }
+    return $ok;
 }
 
+
 =head2 _concatenate_lines
 
  Title   : _concatenate_lines
@@ -597,12 +646,12 @@ END
 =cut
 
 sub _concatenate_lines {
-	my ($self, $s1, $s2) = @_;
-
-	$s1 .= " " if($s1 && ($s1 !~ /-$/) && $s2);
-	return ($s1 ? $s1 : "") . ($s2 ? $s2 : "");
+    my ($self, $s1, $s2) = @_;
+    $s1 .= " " if($s1 && ($s1 !~ /-$/) && $s2);
+    return ($s1 ? $s1 : "") . ($s2 ? $s2 : "");
 }
 
+
 =head2 _filehandle
 
  Title   : _filehandle
@@ -619,6 +668,7 @@ sub _filehandle {
     return $self->_fh(@args);
 }
 
+
 =head2 _guess_format
 
  Title   : _guess_format
@@ -636,56 +686,61 @@ sub _filehandle {
 sub _guess_format {
    my $class = shift;
    return unless $_ = shift;
-   return 'abi'     if /\.ab[i1]$/i;
-   return 'ace'     if /\.ace$/i;
-   return 'alf'     if /\.alf$/i;
-   return 'bsml'    if /\.(bsm|bsml)$/i;
-   return 'ctf'     if /\.ctf$/i;
-   return 'embl'    if /\.(embl|ebl|emb|dat)$/i;
-	return 'entrezgene' if /\.asn$/i;
-   return 'exp'     if /\.exp$/i;
-   return 'fasta'   if /\.(fasta|fast|fas|seq|fa|fsa|nt|aa|fna|faa)$/i;
-   return 'fastq'   if /\.fastq$/i;
-   return 'gcg'     if /\.gcg$/i;
-   return 'genbank' if /\.(gb|gbank|genbank|gbk|gbs)$/i;
-   return 'phd'     if /\.(phd|phred)$/i;
-   return 'pir'     if /\.pir$/i;
-   return 'pln'     if /\.pln$/i;
-   return 'raw'     if /\.(txt)$/i;
-   return 'scf'     if /\.scf$/i;
-   return 'swiss'   if /\.(swiss|sp)$/i;
 
+   return 'abi'        if /\.ab[i1]$/i;
+   return 'ace'        if /\.ace$/i;
+   return 'alf'        if /\.alf$/i;
+   return 'bsml'       if /\.(bsm|bsml)$/i;
+   return 'ctf'        if /\.ctf$/i;
+   return 'embl'       if /\.(embl|ebl|emb|dat)$/i;
+   return 'entrezgene' if /\.asn$/i;
+   return 'exp'        if /\.exp$/i;
+   return 'fasta'      if /\.(fasta|fast|fas|seq|fa|fsa|nt|aa|fna|faa)$/i;
+   return 'fastq'      if /\.fastq$/i;
+   return 'gcg'        if /\.gcg$/i;
+   return 'genbank'    if /\.(gb|gbank|genbank|gbk|gbs)$/i;
+   return 'phd'        if /\.(phd|phred)$/i;
+   return 'pir'        if /\.pir$/i;
+   return 'pln'        if /\.pln$/i;
+   return 'qual'       if /\.qual$/i;
+   return 'raw'        if /\.txt$/i;
+   return 'scf'        if /\.scf$/i;
    # from Strider 1.4 Release Notes: The file name extensions used by
    # Strider 1.4 are ".xdna", ".xdgn", ".xrna" and ".xprt" for DNA,
    # DNA Degenerate, RNA and Protein Sequence Files, respectively
-   return 'strider' if /\.(xdna|xdgn|xrna|xprt)$/i;
-
-   return 'ztr'     if /\.ztr$/i;
+   return 'strider'    if /\.(xdna|xdgn|xrna|xprt)$/i;
+   return 'swiss'      if /\.(swiss|sp)$/i;
+   return 'ztr'        if /\.ztr$/i;
 }
 
+
 sub DESTROY {
-	my $self = shift;
-	$self->close();
+    my $self = shift;
+    $self->close();
 }
 
+
 sub TIEHANDLE {
-	my ($class,$val) = @_;
-	return bless {'seqio' => $val}, $class;
+    my ($class,$val) = @_;
+    return bless {'seqio' => $val}, $class;
 }
 
+
 sub READLINE {
-	my $self = shift;
-	return $self->{'seqio'}->next_seq() unless wantarray;
-	my (@list, $obj);
-	push @list, $obj while $obj = $self->{'seqio'}->next_seq();
-	return @list;
+    my $self = shift;
+    return $self->{'seqio'}->next_seq() || undef unless wantarray;
+    my (@list, $obj);
+    push @list, $obj while $obj = $self->{'seqio'}->next_seq();
+    return @list;
 }
 
+
 sub PRINT {
-	my $self = shift;
-	$self->{'seqio'}->write_seq(@_);
+    my $self = shift;
+    $self->{'seqio'}->write_seq(@_);
 }
 
+
 =head2 sequence_factory
 
  Title   : sequence_factory
@@ -696,22 +751,23 @@ sub PRINT {
 
 =cut
 
-sub sequence_factory{
-   my ($self,$obj) = @_;
+sub sequence_factory {
+   my ($self, $obj) = @_;
    if( defined $obj ) {
-		if( ! ref($obj) || ! $obj->isa('Bio::Factory::SequenceFactoryI') ) {
-			$self->throw("Must provide a valid Bio::Factory::SequenceFactoryI object to ".ref($self)."::sequence_factory()");
-		}
-		$self->{'_seqio_seqfactory'} = $obj;
-		my $builder = $self->sequence_builder();
-		if($builder && $builder->can('sequence_factory') &&
-			(! $builder->sequence_factory())) {
-			$builder->sequence_factory($obj);
-		}
+        if( ! ref($obj) || ! $obj->isa('Bio::Factory::SequenceFactoryI') ) {
+            $self->throw("Must provide a valid Bio::Factory::SequenceFactoryI object to ".ref($self)."::sequence_factory()");
+        }
+        $self->{'_seqio_seqfactory'} = $obj;
+        my $builder = $self->sequence_builder();
+        if($builder && $builder->can('sequence_factory') &&
+            (! $builder->sequence_factory())) {
+            $builder->sequence_factory($obj);
+        }
    }
    $self->{'_seqio_seqfactory'};
 }
 
+
 =head2 object_factory
 
  Title   : object_factory
@@ -724,15 +780,17 @@ sub sequence_factory{
 =cut
 
 sub object_factory{
-	return shift->sequence_factory(@_);
+    return shift->sequence_factory(@_);
 }
 
+
 =head2 sequence_builder
 
  Title   : sequence_builder
  Usage   : $seqio->sequence_builder($seqfactory)
  Function: Get/Set the Bio::Factory::ObjectBuilderI used to build sequence
-           objects.
+           objects. This applies to rich sequence formats only, e.g. genbank
+           but not fasta.
 
            If you do not set the sequence object builder yourself, it
            will in fact be an instance of L<Bio::Seq::SeqBuilder>, and
@@ -743,17 +801,18 @@ sub object_factory{
 
 =cut
 
-sub sequence_builder{
-	my ($self,$obj) = @_;
-	if( defined $obj ) {
-		if( ! ref($obj) || ! $obj->isa('Bio::Factory::ObjectBuilderI') ) {
-			$self->throw("Must provide a valid Bio::Factory::ObjectBuilderI object to ".ref($self)."::sequence_builder()");
-		}
-		$self->{'_object_builder'} = $obj;
-	}
-	$self->{'_object_builder'};
+sub sequence_builder {
+    my ($self, $obj) = @_;
+    if( defined $obj ) {
+        if( ! ref($obj) || ! $obj->isa('Bio::Factory::ObjectBuilderI') ) {
+            $self->throw("Must provide a valid Bio::Factory::ObjectBuilderI object to ".ref($self)."::sequence_builder()");
+        }
+        $self->{'_object_builder'} = $obj;
+    }
+    $self->{'_object_builder'};
 }
 
+
 =head2 location_factory
 
  Title   : location_factory
@@ -766,16 +825,16 @@ sub sequence_builder{
 
 =cut
 
-sub location_factory{
-	my ($self,$obj) = @_;
-	if( defined $obj ) {
-		if( ! ref($obj) || ! $obj->isa('Bio::Factory::LocationFactoryI') ) {
-			$self->throw("Must provide a valid Bio::Factory::LocationFactoryI" .
-							 " object to ".ref($self)."->location_factory()");
-		}
-		$self->{'_seqio_locfactory'} = $obj;
-	}
-	$self->{'_seqio_locfactory'};
+sub location_factory {
+    my ($self,$obj) = @_;
+    if( defined $obj ) {
+        if( ! ref($obj) || ! $obj->isa('Bio::Factory::LocationFactoryI') ) {
+            $self->throw("Must provide a valid Bio::Factory::LocationFactoryI" .
+                             " object to ".ref($self)."->location_factory()");
+        }
+        $self->{'_seqio_locfactory'} = $obj;
+    }
+    $self->{'_seqio_locfactory'};
 }
 
 1;
